@@ -24,20 +24,20 @@
 #include "namespace.h"
 
 static size_t
-grbEncode(int filetype, int memtype, int varID, int levelID, int vlistID, int gridID, int zaxisID, CdiDateTime vDateTime,
-          int tsteptype, int numavg, size_t datasize, const void *data, size_t nmiss, void **gribbuffer, int comptype,
-          void *gribContainers)
+grb_encode(int filetype, int memType, int varID, int levelID, int vlistID, int gridID, int zaxisID, CdiDateTime vDateTime,
+           int tsteptype, int numavg, SizeType datasize, const void *data, size_t numMissVals, void **gribbuffer, int comptype,
+           void *gribContainers)
 {
   size_t nbytes = 0;
 
 #ifdef HAVE_LIBCGRIBEX
   if (filetype == CDI_FILETYPE_GRB && !CDI_gribapi_grib1)
     {
-      size_t gribbuffersize = datasize * 4 + 3000;
+      size_t gribbuffersize = (size_t) datasize * 4 + 3000;
       *gribbuffer = Malloc(gribbuffersize);
 
-      nbytes = cgribexEncode(memtype, varID, levelID, vlistID, gridID, zaxisID, vDateTime, tsteptype, numavg, datasize, data,
-                             nmiss, *gribbuffer, gribbuffersize);
+      nbytes = cgribexEncode(memType, varID, levelID, vlistID, gridID, zaxisID, vDateTime, tsteptype, numavg, datasize, data,
+                             (SizeType) numMissVals, *gribbuffer, gribbuffersize);
     }
   else
 #endif
@@ -48,20 +48,26 @@ grbEncode(int filetype, int memtype, int varID, int levelID, int vlistID, int gr
 #else
       void *gribContainer = (void *) &((gribContainer_t *) gribContainers)[varID];
 #endif
+      bool useFloatInterface = false;
+      int memTypeX = useFloatInterface ? memType : MEMTYPE_DOUBLE;
       const void *datap = data;
-      if (memtype == MEMTYPE_FLOAT)
+
+      // if (useFloatInterface) printf("gribapi write: useFloatInterface\n");
+
+      if (!useFloatInterface && memType == MEMTYPE_FLOAT)
         {
+          // printf("gribapi write: convert float to double\n");
           const float *dataf = (const float *) data;
-          double *datad = (double *) Malloc(datasize * sizeof(double));
-          for (size_t i = 0; i < datasize; ++i) datad[i] = (double) dataf[i];
+          double *datad = (double *) Malloc((size_t) datasize * sizeof(double));
+          for (size_t i = 0; i < (size_t) datasize; ++i) datad[i] = (double) dataf[i];
           datap = (const void *) datad;
         }
 
       size_t gribbuffersize;
-      nbytes = gribapiEncode(varID, levelID, vlistID, gridID, zaxisID, vDateTime, tsteptype, numavg, (long) datasize, datap, nmiss,
-                             gribbuffer, &gribbuffersize, comptype, gribContainer);
+      nbytes = gribapiEncode(memTypeX, varID, levelID, vlistID, gridID, zaxisID, vDateTime, tsteptype, numavg, (size_t) datasize,
+                             datap, (SizeType) numMissVals, gribbuffer, &gribbuffersize, comptype, gribContainer);
 
-      if (memtype == MEMTYPE_FLOAT) Free((void *) datap);
+      if (!useFloatInterface && memType == MEMTYPE_FLOAT) Free((void *) datap);
     }
 #else
   {
@@ -77,7 +83,7 @@ grbEncode(int filetype, int memtype, int varID, int levelID, int vlistID, int gr
 static size_t
 grbSzip(int filetype, void *gribbuffer, size_t gribbuffersize)
 {
-  size_t buffersize = gribbuffersize + 1000; /* compressed record can be greater than source record */
+  size_t buffersize = gribbuffersize + 1000;  // compressed record can be greater than source record
   void *buffer = Malloc(buffersize);
 
   // memcpy(buffer, gribbuffer, gribbuffersize);
@@ -109,64 +115,66 @@ typedef struct
   char levelist[8];
 } FDB_Keys;
 
-void
+#ifdef HAVE_LIBFDB5
+static void
 cdi_fdb_store(void *fdbHandle, const char *filename, void *gribbuffer, size_t nbytes, const FDB_Keys *fdbKeys)
 {
-#ifdef HAVE_LIBFDB5
   size_t len = strlen(filename);
-  if (len == 4) Error("FDB keys missing!");
+  if (len == 6) Error("FDB keys missing!");
 
-  KeyValueEntry keyValue;
+  KeyValueItem keyValue;
   keyValue.item = NULL;
-  decode_fdbitem(filename + 4, &keyValue);
+  decode_fdbitem(filename + 6, &keyValue);
 
   if (keyValue.numKeys == 0) Error("FDB keys missing!");
 
-  const char *class = NULL;
-  const char *stream = NULL;
-  const char *expver = NULL;
-  for (int i = 0; i < keyValue.numKeys; i++)
+  bool expverDefined = false;
+  bool classDefined = false;
+  for (int k = 0; k < keyValue.numKeys; k++)
     {
       // clang-format off
-      if      (strcmp(keyValue.keys[i], "class") == 0) class = keyValue.values[i];
-      else if (strcmp(keyValue.keys[i], "stream") == 0) stream = keyValue.values[i];
-      else if (strcmp(keyValue.keys[i], "expver") == 0) expver = keyValue.values[i];
-      else Error("Unsupported FDB parameter: %s=%s", keyValue.keys[i], keyValue.values[i]);
+      if      (!expverDefined && str_is_equal(keyValue.keys[k], "expver")) expverDefined = true;
+      else if (!classDefined  && str_is_equal(keyValue.keys[k], "class")) classDefined = true;
       // clang-format on
     }
 
-  if (!class) Error("FDB parameter <class> undefined!");
-  if (!stream) Error("FDB parameter <stream> undefined!");
-  if (!expver) Error("FDB parameter <expver> undefined!");
+  if (!expverDefined) Error("FDB parameter <expver> undefined!");
+  if (!classDefined) Error("FDB parameter <class> undefined!");
 
   if (CDI_Debug)
     {
-      printf("{class=%s,expver=%s,stream=%s,date=%s,time=%s,domain=g}", class, expver, stream, fdbKeys->date, fdbKeys->time);
+      printf("{");
+      for (int k = 0; k < keyValue.numKeys; k++)
+        {
+          printf("%s%s=%s", (k > 0) ? "," : "", keyValue.keys[k], keyValue.values[k]);
+        }
+      printf(",date=%s,time=%s,domain=g}", fdbKeys->date, fdbKeys->time);
       printf("{type=an,levtype=%s}{step=0,", fdbKeys->levtype);
       if (fdbKeys->levelist[0]) printf("levelist=%s,", fdbKeys->levelist);
       printf("param=%s},length=%zu\n", fdbKeys->param, nbytes);
     }
 
   fdb_key_t *key;
-  fdb_new_key(&key);
-  fdb_key_add(key, "class", class);
-  fdb_key_add(key, "expver", expver);
-  fdb_key_add(key, "stream", stream);
-  fdb_key_add(key, "domain", "g");
-  fdb_key_add(key, "date", fdbKeys->date);
-  fdb_key_add(key, "time", fdbKeys->time);
-  fdb_key_add(key, "type", "an");
-  fdb_key_add(key, "levtype", fdbKeys->levtype);
-  fdb_key_add(key, "step", "0");
-  fdb_key_add(key, "param", fdbKeys->param);
-  if (fdbKeys->levelist[0]) fdb_key_add(key, "levelist", fdbKeys->levelist);
+  check_fdb_error(fdb_new_key(&key));
+  for (int k = 0; k < keyValue.numKeys; k++)
+    {
+      check_fdb_error(fdb_key_add(key, keyValue.keys[k], keyValue.values[k]));
+    }
+  check_fdb_error(fdb_key_add(key, "domain", "g"));
+  check_fdb_error(fdb_key_add(key, "date", fdbKeys->date));
+  check_fdb_error(fdb_key_add(key, "time", fdbKeys->time));
+  check_fdb_error(fdb_key_add(key, "type", "an"));
+  check_fdb_error(fdb_key_add(key, "levtype", fdbKeys->levtype));
+  check_fdb_error(fdb_key_add(key, "step", "0"));
+  check_fdb_error(fdb_key_add(key, "param", fdbKeys->param));
+  if (fdbKeys->levelist[0]) check_fdb_error(fdb_key_add(key, "levelist", fdbKeys->levelist));
 
-  fdb_archive(fdbHandle, key, gribbuffer, nbytes);
+  check_fdb_error(fdb_archive(fdbHandle, key, gribbuffer, nbytes));
   // alternative: write to tmpfile and use C++ code from fdb_write
 
-  fdb_delete_key(key);
-#endif
+  check_fdb_error(fdb_delete_key(key));
 }
+#endif
 
 static int
 map_grib2_param(int pnum, int pcat, int pdis)
@@ -210,14 +218,14 @@ fillup_gribbuffer(size_t nbytes, unsigned char *gribbuffer)
 void
 grbCopyRecord(stream_t *streamptr2, stream_t *streamptr1)
 {
-  const int filetype = streamptr1->filetype;
-  const int fileID1 = streamptr1->fileID;
-  const int fileID2 = streamptr2->fileID;
-  const int tsID = streamptr1->curTsID;
-  const int vrecID = streamptr1->tsteps[tsID].curRecID;
-  const int recID = streamptr1->tsteps[tsID].recIDs[vrecID];
+  int filetype = streamptr1->filetype;
+  int fileID1 = streamptr1->fileID;
+  int fileID2 = streamptr2->fileID;
+  int tsID = streamptr1->curTsID;
+  int vrecID = streamptr1->tsteps[tsID].curRecID;
+  int recID = streamptr1->tsteps[tsID].recIDs[vrecID];
   const record_t *record = &streamptr1->tsteps[tsID].records[recID];
-  const off_t recpos = record->position;
+  off_t recpos = record->position;
   size_t recsize = record->size;
 
   void *gribbuffer = NULL;
@@ -225,14 +233,15 @@ grbCopyRecord(stream_t *streamptr2, stream_t *streamptr1)
   if (streamptr1->protocol == CDI_PROTOCOL_FDB)
     {
 #ifdef HAVE_LIBFDB5
-      void *fdbItem = streamptr1->tsteps[tsID].records[recID].fdbItem;
-      if (!fdbItem) Error("fdbItem not available!");
+      int fdbItemIndex = streamptr1->tsteps[tsID].records[recID].fdbItemIndex;
+      if (fdbItemIndex == -1) Error("fdbItem not available!");
 
       size_t buffersize = 0;
-      recsize = fdb_read_record(streamptr1->protocolData, fdbItem, &buffersize, &gribbuffer);
+      recsize
+          = cdi_fdb_read_record(streamptr1->protocolData, &(streamptr1->fdbKeyValueList[fdbItemIndex]), &buffersize, &gribbuffer);
 
       // round up recsize to next multiple of 8
-      const size_t gribbuffersize = ((recsize + 7U) & ~7U);
+      size_t gribbuffersize = ((recsize + 7U) & ~7U);
 
       gribbuffer = (unsigned char *) Realloc(gribbuffer, gribbuffersize);
 #endif
@@ -242,7 +251,7 @@ grbCopyRecord(stream_t *streamptr2, stream_t *streamptr1)
       fileSetPos(fileID1, recpos, SEEK_SET);
 
       // round up recsize to next multiple of 8
-      const size_t gribbuffersize = ((recsize + 7U) & ~7U);
+      size_t gribbuffersize = ((recsize + 7U) & ~7U);
 
       gribbuffer = (unsigned char *) Malloc(gribbuffersize);
 
@@ -294,7 +303,7 @@ grbCopyRecord(stream_t *streamptr2, stream_t *streamptr1)
     {
       grib_handle *gh = grib_handle_new_from_message(NULL, (void *) gribbuffer, recsize);
 
-      const int scanModeIN = gribapiGetScanningMode(gh);
+      int scanModeIN = gribapiGetScanningMode(gh);
 
       grib_handle_delete(gh);
 
@@ -303,20 +312,20 @@ grbCopyRecord(stream_t *streamptr2, stream_t *streamptr1)
 
       if (scanModeIN != cdiGribDataScanningMode.value)
         {
-          size_t nmiss = 0;
+          size_t numMissVals = 0;
 
-          const int vlistID = streamptr1->vlistID;
-          const int varID = record->varID;
-          const int levelID = record->levelID;
-          const int gridID = vlistInqVarGrid(vlistID, varID);
+          int vlistID = streamptr1->vlistID;
+          int varID = record->varID;
+          int levelID = record->levelID;
+          int gridID = vlistInqVarGrid(vlistID, varID);
 
           size_t gridsize = gridInqSize(gridID);
           if (vlistNumber(vlistID) != CDI_REAL) gridsize *= 2;
-          double *data = (double *) malloc(gridsize * sizeof(double));
+          double *data = (double *) Malloc(gridsize * sizeof(double));
 
           if (cdiDebugExt >= 20) Message(" processing varID %d; levelID %d", varID, levelID);
 
-          grb_write_var_slice(streamptr2, varID, levelID, MEMTYPE_DOUBLE, (const void *) data, nmiss);
+          grb_write_var_slice(streamptr2, varID, levelID, MEMTYPE_DOUBLE, (const void *) data, numMissVals);
 
           free(data);
         }
@@ -327,27 +336,27 @@ grbCopyRecord(stream_t *streamptr2, stream_t *streamptr1)
   if (filetype == CDI_FILETYPE_GRB)
     {
       size_t unzipsize;
-      const int izip = gribGetZip(recsize, gribbuffer, &unzipsize);
+      int izip = gribGetZip(recsize, (unsigned char *) gribbuffer, &unzipsize);
 
       if (izip == 0 && (streamptr2->comptype == CDI_COMPRESS_SZIP || streamptr2->comptype == CDI_COMPRESS_AEC))
         nbytes = grbSzip(filetype, gribbuffer, nbytes);
     }
 
-  fillup_gribbuffer(nbytes, gribbuffer);
+  fillup_gribbuffer(nbytes, (unsigned char *) gribbuffer);
 
   if (streamptr2->protocol == CDI_PROTOCOL_FDB)
     {
-      const int vlistID = streamptr1->vlistID;
-      const int varID = record->varID;
-      const int zaxisID = vlistInqVarZaxis(vlistID, varID);
-      const int zaxisType = zaxisInqType(zaxisID);
-      const CdiDateTime vDateTime = streamptr1->tsteps[tsID].taxis.vDateTime;
+      int vlistID = streamptr1->vlistID;
+      int varID = record->varID;
+      int zaxisID = vlistInqVarZaxis(vlistID, varID);
+      int zaxisType = zaxisInqType(zaxisID);
+      CdiDateTime vDateTime = streamptr1->tsteps[tsID].taxis.vDateTime;
 
       FDB_Keys fdbKeys;
       snprintf(fdbKeys.date, sizeof(fdbKeys.date), "%d", (int) cdiDate_get(vDateTime.date));
-      snprintf(fdbKeys.time, sizeof(fdbKeys.time), "%04d", (short)(cdiTime_get(vDateTime.time) / 100));
+      snprintf(fdbKeys.time, sizeof(fdbKeys.time), "%04d", (short) (cdiTime_get(vDateTime.time) / 100));
       snprintf(fdbKeys.param, sizeof(fdbKeys.param), "%d", get_fdb_param(record->param));
-      const bool isML = (zaxisType == ZAXIS_HYBRID || zaxisType == ZAXIS_HYBRID_HALF);
+      bool isML = (zaxisType == ZAXIS_HYBRID || zaxisType == ZAXIS_HYBRID_HALF);
       snprintf(fdbKeys.levtype, sizeof(fdbKeys.levtype), "%s", isML ? "ml" : "sfc");
       fdbKeys.levelist[0] = 0;
       if (isML) snprintf(fdbKeys.levelist, sizeof(fdbKeys.levelist), "%d", isML ? record->ilevel : 0);
@@ -358,34 +367,30 @@ grbCopyRecord(stream_t *streamptr2, stream_t *streamptr1)
     }
   else
     {
-      const size_t nwrite = fileWrite(fileID2, gribbuffer, nbytes);
-      if (nwrite != nbytes)
-        {
-          perror(__func__);
-          Error("Could not write record for copying!");
-        }
+      size_t nwrite = fileWrite(fileID2, gribbuffer, nbytes);
+      if (nwrite != nbytes) SysError("Could not write record for copying!");
     }
 
   Free(gribbuffer);
 }
 
 void
-grb_write_var_slice(stream_t *streamptr, int varID, int levelID, int memtype, const void *data, size_t nmiss)
+grb_write_var_slice(stream_t *streamptr, int varID, int levelID, int memtype, const void *data, size_t numMissVals)
 {
-  const int filetype = streamptr->filetype;
-  const int fileID = streamptr->fileID;
-  const int vlistID = streamptr->vlistID;
-  const int gridID = vlistInqVarGrid(vlistID, varID);
-  const int zaxisID = vlistInqVarZaxis(vlistID, varID);
-  const int tsteptype = vlistInqVarTsteptype(vlistID, varID);
-  const int tsID = streamptr->curTsID;
-  const CdiDateTime vDateTime = streamptr->tsteps[tsID].taxis.vDateTime;
-  const int numavg = (tsteptype == TSTEP_AVG) ? streamptr->tsteps[tsID].taxis.numavg : 0;
+  int filetype = streamptr->filetype;
+  int fileID = streamptr->fileID;
+  int vlistID = streamptr->vlistID;
+  int gridID = vlistInqVarGrid(vlistID, varID);
+  int zaxisID = vlistInqVarZaxis(vlistID, varID);
+  int tsteptype = vlistInqVarTsteptype(vlistID, varID);
+  int tsID = streamptr->curTsID;
+  CdiDateTime vDateTime = streamptr->tsteps[tsID].taxis.vDateTime;
+  int numavg = (tsteptype == TSTEP_AVG) ? streamptr->tsteps[tsID].taxis.numavg : 0;
   int comptype = streamptr->comptype;
 
   if (CDI_Debug) Message("gridID = %d zaxisID = %d", gridID, zaxisID);
 
-  const size_t datasize = gridInqSize(gridID);
+  SizeType datasize = gridInqSize(gridID);
 
   if (comptype != CDI_COMPRESS_JPEG && comptype != CDI_COMPRESS_SZIP && comptype != CDI_COMPRESS_AEC) comptype = CDI_COMPRESS_NONE;
 
@@ -397,8 +402,8 @@ grb_write_var_slice(stream_t *streamptr, int varID, int levelID, int memtype, co
     }
 
   void *gribbuffer = NULL;
-  size_t nbytes = grbEncode(filetype, memtype, varID, levelID, vlistID, gridID, zaxisID, vDateTime, tsteptype, numavg, datasize,
-                            data, nmiss, &gribbuffer, comptype, streamptr->gribContainers);
+  size_t nbytes = grb_encode(filetype, memtype, varID, levelID, vlistID, gridID, zaxisID, vDateTime, tsteptype, numavg, datasize,
+                             data, numMissVals, &gribbuffer, comptype, streamptr->gribContainers);
 
   if (filetype == CDI_FILETYPE_GRB && (comptype == CDI_COMPRESS_SZIP || comptype == CDI_COMPRESS_AEC))
     nbytes = grbSzip(filetype, gribbuffer, nbytes);
@@ -408,11 +413,7 @@ grb_write_var_slice(stream_t *streamptr, int varID, int levelID, int memtype, co
     case CDI_PROTOCOL_ACROSS:
       {
 #ifdef HAVE_ACROSS
-        if (across_write_grib_message(streamptr, gribbuffer, nbytes))
-          {
-            Error("Failed to write GRIB slice!");
-            break;
-          }
+        if (across_write_grib_message(streamptr, gribbuffer, nbytes)) SysError("Failed to write GRIB slice!");
 #endif
       }
       break;
@@ -420,14 +421,14 @@ grb_write_var_slice(stream_t *streamptr, int varID, int levelID, int memtype, co
     case CDI_PROTOCOL_FDB:
       {
 #ifdef HAVE_LIBFDB5
-        const int zaxisType = zaxisInqType(zaxisID);
-        const double level = zaxisInqLevel(zaxisID, levelID);
+        int zaxisType = zaxisInqType(zaxisID);
+        double level = zaxisInqLevel(zaxisID, levelID);
 
         FDB_Keys fdbKeys;
         snprintf(fdbKeys.date, sizeof(fdbKeys.date), "%d", (int) cdiDate_get(vDateTime.date));
-        snprintf(fdbKeys.time, sizeof(fdbKeys.time), "%04d", (short)(cdiTime_get(vDateTime.time) / 100));
+        snprintf(fdbKeys.time, sizeof(fdbKeys.time), "%04d", (short) (cdiTime_get(vDateTime.time) / 100));
         snprintf(fdbKeys.param, sizeof(fdbKeys.param), "%d", get_fdb_param(vlistInqVarParam(vlistID, varID)));
-        const bool isML = (zaxisType == ZAXIS_HYBRID || zaxisType == ZAXIS_HYBRID_HALF);
+        bool isML = (zaxisType == ZAXIS_HYBRID || zaxisType == ZAXIS_HYBRID_HALF);
         snprintf(fdbKeys.levtype, sizeof(fdbKeys.levtype), "%s", isML ? "ml" : "sfc");
         fdbKeys.levelist[0] = 0;
         int ilevel = (isML) ? (int) level : 0;
@@ -444,12 +445,8 @@ grb_write_var_slice(stream_t *streamptr, int varID, int levelID, int memtype, co
         size_t (*myFileWrite)(int fileID, const void *restrict buffer, size_t len)
             = (size_t(*)(int, const void *restrict, size_t)) namespaceSwitchGet(NSSWITCH_FILE_WRITE).func;
 
-        const size_t nwrite = myFileWrite(fileID, gribbuffer, nbytes);
-        if (nwrite != nbytes)
-          {
-            perror(__func__);
-            Error("Failed to write GRIB slice!");
-          }
+        size_t nwrite = myFileWrite(fileID, gribbuffer, nbytes);
+        if (nwrite != nbytes) SysError("Failed to write GRIB slice!");
       }
       break;
     }
@@ -458,44 +455,44 @@ grb_write_var_slice(stream_t *streamptr, int varID, int levelID, int memtype, co
 }
 
 void
-grb_write_var(stream_t *streamptr, int varID, int memtype, const void *data, size_t nmiss)
+grb_write_var(stream_t *streamptr, int varID, int memtype, const void *data, size_t numMissVals)
 {
-  const int vlistID = streamptr->vlistID, gridID = vlistInqVarGrid(vlistID, varID), zaxisID = vlistInqVarZaxis(vlistID, varID),
-            nlevs = zaxisInqSize(zaxisID);
-  const size_t gridsize = gridInqSize(gridID);
-  const double missval = vlistInqVarMissval(vlistID, varID);
+  int vlistID = streamptr->vlistID, gridID = vlistInqVarGrid(vlistID, varID), zaxisID = vlistInqVarZaxis(vlistID, varID),
+      nlevs = zaxisInqSize(zaxisID);
+  size_t gridsize = (size_t) gridInqSize(gridID);
+  double missval = vlistInqVarMissval(vlistID, varID);
 
-  const size_t chunkLen = gridsize;
+  size_t chunkLen = gridsize;
   if (memtype == MEMTYPE_FLOAT)
     for (int levelID = 0; levelID < nlevs; levelID++)
       {
-        const float *restrict fdata = ((const float *) data) + levelID * gridsize;
+        const float *restrict fdata = ((const float *) data) + (size_t) levelID * gridsize;
 
-        size_t nmiss_slice = 0;
-        if (nmiss)
-          for (size_t i = 0; i < chunkLen; ++i) nmiss_slice += DBL_IS_EQUAL(fdata[i], missval);
+        size_t numMissVals_slice = 0;
+        if (numMissVals)
+          for (size_t i = 0; i < chunkLen; ++i) numMissVals_slice += DBL_IS_EQUAL(fdata[i], missval);
 
-        grb_write_var_slice(streamptr, varID, levelID, memtype, fdata, nmiss_slice);
+        grb_write_var_slice(streamptr, varID, levelID, memtype, fdata, numMissVals_slice);
       }
   else
     for (int levelID = 0; levelID < nlevs; levelID++)
       {
-        const double *restrict ddata = ((const double *) data) + levelID * gridsize;
+        const double *restrict ddata = ((const double *) data) + (size_t) levelID * gridsize;
 
-        size_t nmiss_slice = 0;
-        if (nmiss)
-          for (size_t i = 0; i < chunkLen; ++i) nmiss_slice += DBL_IS_EQUAL(ddata[i], missval);
+        size_t numMissVals_slice = 0;
+        if (numMissVals)
+          for (size_t i = 0; i < chunkLen; ++i) numMissVals_slice += DBL_IS_EQUAL(ddata[i], missval);
 
-        grb_write_var_slice(streamptr, varID, levelID, memtype, ddata, nmiss_slice);
+        grb_write_var_slice(streamptr, varID, levelID, memtype, ddata, numMissVals_slice);
       }
 }
 
 void
-grb_write_record(stream_t *streamptr, int memtype, const void *data, size_t nmiss)
+grb_write_record(stream_t *streamptr, int memtype, const void *data, size_t numMissVals)
 {
-  const int varID = streamptr->record->varID;
-  const int levelID = streamptr->record->levelID;
-  grb_write_var_slice(streamptr, varID, levelID, memtype, data, nmiss);
+  int varID = streamptr->record->varID;
+  int levelID = streamptr->record->levelID;
+  grb_write_var_slice(streamptr, varID, levelID, memtype, data, numMissVals);
 }
 
 #endif
