@@ -26,7 +26,7 @@ cdfCopyRecord(stream_t *streamptr2, stream_t *streamptr1)
   int recID = streamptr1->tsteps[tsID].recIDs[vrecID];
   int ivarID = streamptr1->tsteps[tsID].records[recID].varID;
   int gridID = vlistInqVarGrid(vlistID1, ivarID);
-  size_t datasize = gridInqSize(gridID);
+  size_t datasize = (size_t) gridInqSize(gridID);
   int datatype = vlistInqVarDatatype(vlistID1, ivarID);
   int memtype = (datatype != CDI_DATATYPE_FLT32) ? MEMTYPE_DOUBLE : MEMTYPE_FLOAT;
 
@@ -98,8 +98,8 @@ struct idSearch
 };
 
 static inline struct idSearch
-cdfSearchIDBySize(size_t startIdx, size_t numIDs, ncgrid_t ncgrid[/*numIDs*/], int ncIDType, int searchType, int searchSize,
-                  int (*typeInq)(int id), SizeType (*sizeInq)(int id))
+cdfSearchIDBySize(size_t startIdx, size_t numIDs, const ncgrid_t ncgrid[/*numIDs*/], int ncIDType, int searchType,
+                  SizeType searchSize, int (*typeInq)(int id), SizeType (*sizeInq)(int id))
 {
   int numNonMatching = 0, foundID = CDI_UNDEFID;
   size_t foundIdx = SIZE_MAX;
@@ -110,7 +110,7 @@ cdfSearchIDBySize(size_t startIdx, size_t numIDs, ncgrid_t ncgrid[/*numIDs*/], i
           int id0 = ncgrid[index].gridID, id0Type = typeInq(id0);
           if (id0Type == searchType)
             {
-              int size0 = sizeInq(id0);
+              SizeType size0 = sizeInq(id0);
               if (searchSize == size0)
                 {
                   foundID = ncgrid[index].ncIDs[ncIDType];
@@ -135,10 +135,10 @@ cdfDefSPorFC(stream_t *streamptr, int gridID, int gridIndex, char *axisname, siz
 {
   ncgrid_t *ncgrid = streamptr->ncgrid;
 
-  size_t dimlen = gridInqSize(gridID) / 2;
+  SizeType dimlen = gridInqSize(gridID) / 2;
 
   struct idSearch search
-      = cdfSearchIDBySize(0, (size_t) gridIndex, ncgrid, CDF_DIMID_Y, gridRefType, (int) dimlen, gridInqType, cdfGridInqHalfSize);
+      = cdfSearchIDBySize(0, (size_t) gridIndex, ncgrid, CDF_DIMID_Y, gridRefType, dimlen, gridInqType, cdfGridInqHalfSize);
   int dimID = search.foundID;
   int iz = search.numNonMatching;
 
@@ -155,7 +155,7 @@ cdfDefSPorFC(stream_t *streamptr, int gridID, int gridIndex, char *axisname, siz
           cdf_redef(fileID);
         }
 
-      cdf_def_dim(fileID, axisname, dimlen, &dimID);
+      cdf_def_dim(fileID, axisname, (size_t) dimlen, &dimID);
 
       if (switchNCMode)
         {
@@ -258,7 +258,7 @@ cdfDefTrajLatLon(stream_t *streamptr, int gridID, int gridIndex, const struct cd
   nc_type xtype = grid_inq_xtype(gridID);
   ncgrid_t *ncgrid = streamptr->ncgrid;
 
-  size_t dimlen = inqs->axisSize(gridID);
+  SizeType dimlen = inqs->axisSize(gridID);
   if (dimlen != 1) Error("%c size isn't 1 for %s grid!", inqs->axisSym, gridNamePtr(gridInqType(gridID)));
 
   int ncvarid = ncgrid[gridIndex].ncIDs[inqs->dimIdx];
@@ -553,10 +553,10 @@ cdfGridCompress(int fileID, int ncvarid, size_t gridsize, int filetype, int comp
 static struct cdfPostDefActionList *
 cdfDefAxisCommon(stream_t *streamptr, int gridID, int gridIndex, int ndims, bool addVarToGrid,
                  const struct cdfDefGridAxisInqs *gridAxisInq, int axisKey, char axisLetter,
-                 void (*finishCyclicBounds)(double *pbounds, size_t dimlen, const double *pvals))
+                 void (*finishCyclicBounds)(double *pbounds, SizeType dimlen, const double *pvals))
 {
   int dimID = CDI_UNDEFID;
-  size_t dimlen = gridAxisInq->axisSize(gridID);
+  SizeType dimlen = gridAxisInq->axisSize(gridID);
   nc_type xtype = grid_inq_xtype(gridID);
 
   ncgrid_t *ncgrid = streamptr->ncgrid;
@@ -574,7 +574,7 @@ cdfDefAxisCommon(stream_t *streamptr, int gridID, int gridIndex, int ndims, bool
       int gridtype0 = gridInqType(gridID0);
       if (gridtype0 == GRID_GAUSSIAN || gridtype0 == GRID_LONLAT || gridtype0 == GRID_PROJECTION || gridtype0 == GRID_GENERIC)
         {
-          size_t dimlen0 = gridAxisInq->axisSize(gridID0);
+          SizeType dimlen0 = gridAxisInq->axisSize(gridID0);
           char dimname0[CDI_MAX_NAME];
           dimname0[0] = 0;
           length = sizeof(dimname0);
@@ -616,9 +616,9 @@ cdfDefAxisCommon(stream_t *streamptr, int gridID, int gridIndex, int ndims, bool
       if (ndims)
         {
           if (dimname[0] == 0) strcpy(dimname, axisname);
-          dimID = checkDimName(fileID, dimlen, dimname);
+          dimID = checkDimName(fileID, (size_t) dimlen, dimname);
 
-          if (dimID == CDI_UNDEFID) cdf_def_dim(fileID, dimname, dimlen, &dimID);
+          if (dimID == CDI_UNDEFID) cdf_def_dim(fileID, dimname, (size_t) dimlen, &dimID);
         }
 
       if (hasVals)
@@ -633,8 +633,8 @@ cdfDefAxisCommon(stream_t *streamptr, int gridID, int gridIndex, int ndims, bool
 
           if (chunkType == CDI_CHUNK_GRID && dimlen > ChunkSizeLim) chunkType = CDI_CHUNK_LINES;
 
-          size_t chunk = calc_chunksize_x(chunkType, chunkSize, dimlen, true);
-          cdfGridCompress(fileID, ncvarid, dimlen, streamptr->filetype, streamptr->comptype, &chunk);
+          size_t chunk = calc_chunksize_x(chunkType, chunkSize, (size_t) dimlen, true);
+          cdfGridCompress(fileID, ncvarid, (size_t) dimlen, streamptr->filetype, streamptr->comptype, &chunk);
 
           cdfPutGridStdAtts(fileID, ncvarid, gridID, axisLetter);
           {
@@ -648,14 +648,14 @@ cdfDefAxisCommon(stream_t *streamptr, int gridID, int gridIndex, int ndims, bool
           bool genBounds = false, hasBounds = gridInqPropPresence(gridID, gridAxisInq->bndsQueryKey);
           bool grid_is_cyclic = (gridIsCircular(gridID) > 0);
           double *restrict pbounds;
-          size_t nvertex = gridInqNvertex(gridID);
+          size_t nvertex = (size_t) gridInqNvertex(gridID);
           if (CDI_CMOR_Mode && grid_is_cyclic && !hasBounds)
             {
               const double *pvals = gridAxisInq->axisValsPtr(gridID);
               genBounds = true;
               nvertex = 2;
-              pbounds = (double *) Malloc(2 * dimlen * sizeof(double));
-              for (size_t i = 0; i < dimlen - 1; ++i)
+              pbounds = (double *) Malloc(2 * (size_t) dimlen * sizeof(double));
+              for (size_t i = 0; i < (size_t) dimlen - 1; ++i)
                 {
                   pbounds[i * 2 + 1] = (pvals[i] + pvals[i + 1]) * 0.5;
                   pbounds[i * 2 + 2] = (pvals[i] + pvals[i + 1]) * 0.5;
@@ -701,14 +701,14 @@ cdfDefAxisCommon(stream_t *streamptr, int gridID, int gridIndex, int ndims, bool
 }
 
 static void
-finishCyclicXBounds(double *pbounds, size_t dimlen, const double *pvals)
+finishCyclicXBounds(double *pbounds, SizeType dimlen, const double *pvals)
 {
   pbounds[0] = (pvals[0] + pvals[dimlen - 1] - 360) * 0.5;
   pbounds[2 * dimlen - 1] = (pvals[dimlen - 1] + pvals[0] + 360) * 0.5;
 }
 
 static void
-finishCyclicYBounds(double *pbounds, size_t dimlen, const double *pvals)
+finishCyclicYBounds(double *pbounds, SizeType dimlen, const double *pvals)
 {
   pbounds[0] = copysign(90.0, pvals[0]);
   pbounds[2 * dimlen - 1] = copysign(90.0, pvals[dimlen - 1]);
@@ -940,9 +940,9 @@ cdfDefCurvilinear(stream_t *streamptr, int gridID, int gridIndex)
 {
   ncgrid_t *ncgrid = streamptr->ncgrid;
 
-  size_t dimlen = gridInqSize(gridID);
-  size_t xdimlen = gridInqXsize(gridID);
-  size_t ydimlen = gridInqYsize(gridID);
+  SizeType dimlen = gridInqSize(gridID);
+  SizeType xdimlen = gridInqXsize(gridID);
+  SizeType ydimlen = gridInqYsize(gridID);
 
   int xdimID = CDI_UNDEFID, ydimID = CDI_UNDEFID;
   int ncxvarid = CDI_UNDEFID, ncyvarid = CDI_UNDEFID, ncavarid = CDI_UNDEFID;
@@ -950,8 +950,8 @@ cdfDefCurvilinear(stream_t *streamptr, int gridID, int gridIndex)
   size_t ofs = 0;
   do
     {
-      struct idSearch search = cdfSearchIDBySize(ofs, (size_t) gridIndex, ncgrid, CDF_DIMID_X, GRID_CURVILINEAR, (int) dimlen,
-                                                 gridInqType, gridInqSize);
+      struct idSearch search
+          = cdfSearchIDBySize(ofs, (size_t) gridIndex, ncgrid, CDF_DIMID_X, GRID_CURVILINEAR, dimlen, gridInqType, gridInqSize);
       size_t index = search.foundIdx;
       if (index != SIZE_MAX)
         {
@@ -977,7 +977,7 @@ cdfDefCurvilinear(stream_t *streamptr, int gridID, int gridIndex)
   if (xdimID == CDI_UNDEFID || ydimID == CDI_UNDEFID)
     {
       struct cdfDefIrregularGridCommonIDs createdIDs = cdfDefIrregularGridCommon(
-          streamptr, gridID, xdimlen, ydimlen, 3, "x", 4, "nv4",
+          streamptr, gridID, (size_t) xdimlen, (size_t) ydimlen, 3, "x", 4, "nv4",
           gridInqPropPresence(gridID, GRID_PROP_XBOUNDS) || gridInqPropPresence(gridID, GRID_PROP_YBOUNDS));
       xdimID = createdIDs.xdimID;
       ydimID = createdIDs.ydimID;
@@ -1001,7 +1001,7 @@ cdfDefUnstructured(stream_t *streamptr, int gridID, int gridIndex)
 {
   ncgrid_t *ncgrid = streamptr->ncgrid;
 
-  size_t dimlen = gridInqSize(gridID);
+  SizeType dimlen = gridInqSize(gridID);
 
   int dimID = CDI_UNDEFID;
   int ncxvarid = CDI_UNDEFID, ncyvarid = CDI_UNDEFID, ncavarid = CDI_UNDEFID;
@@ -1009,8 +1009,8 @@ cdfDefUnstructured(stream_t *streamptr, int gridID, int gridIndex)
   size_t ofs = 0;
   do
     {
-      struct idSearch search = cdfSearchIDBySize(ofs, (size_t) gridIndex, ncgrid, CDF_DIMID_X, GRID_UNSTRUCTURED, (int) dimlen,
-                                                 gridInqType, gridInqSize);
+      struct idSearch search
+          = cdfSearchIDBySize(ofs, (size_t) gridIndex, ncgrid, CDF_DIMID_X, GRID_UNSTRUCTURED, dimlen, gridInqType, gridInqSize);
       size_t index = search.foundIdx;
       if (index != SIZE_MAX)
         {
@@ -1037,7 +1037,7 @@ cdfDefUnstructured(stream_t *streamptr, int gridID, int gridIndex)
     {
       size_t nvertex = (size_t) gridInqNvertex(gridID);
       struct cdfDefIrregularGridCommonIDs createdIDs
-          = cdfDefIrregularGridCommon(streamptr, gridID, dimlen, 1, 2, "ncells", nvertex, "vertices", nvertex > 0);
+          = cdfDefIrregularGridCommon(streamptr, gridID, (size_t) dimlen, 1, 2, "ncells", nvertex, "vertices", nvertex > 0);
       dimID = createdIDs.xdimID;
       ncxvarid = createdIDs.ncxvarid;
       ncyvarid = createdIDs.ncyvarid;
@@ -1224,8 +1224,9 @@ cdf_def_vct_cf(stream_t *streamptr, int zaxisID, int nclevID, int ncbndsID, int
       double *restrict vctptr = (double *) zaxisInqVctPtr(zaxisID);
       if (p0status == 0 && IS_NOT_EQUAL(p0value, 0))
         {
-          double *restrict temp = (double *) Malloc((size_t) ilev * sizeof(*temp));
-          for (size_t i = 0; i < (size_t) ilev; ++i) temp[i] = vctptr[i] / p0value;
+          double *restrict temp = (double *) Malloc((size_t) 2 * ilev * sizeof(*temp));
+          memcpy(temp, vctptr, (size_t) 2 * ilev * sizeof(*temp));
+          for (size_t i = 0; i < (size_t) ilev; ++i) temp[i] /= p0value;
           vctptr = temp;
         }
 
@@ -1380,7 +1381,7 @@ cdf_def_zaxis_hybrid_cf(stream_t *streamptr, int type, int *ncvaridp, int zaxisI
 
   char p0name[CDI_MAX_NAME];
   p0name[0] = 0;
-  double p0value = 1;
+  static double p0value = 1;
   int p0varid = CDI_UNDEFID;
   int p0status = cdiInqKeyFloat(zaxisID, CDI_GLOBAL, CDI_KEY_P0VALUE, &p0value);
   if (p0status == CDI_NOERR)
@@ -1455,7 +1456,7 @@ cdf_def_zaxis_hybrid_cf(stream_t *streamptr, int type, int *ncvaridp, int zaxisI
   int ncbvarid = CDI_UNDEFID;
   int nvdimID = CDI_UNDEFID;
 
-  double *buffer = (double *) malloc(2 * dimlen * sizeof(double));
+  double *buffer = (double *) Malloc(2 * dimlen * sizeof(double));
   double *lbounds = buffer;
   double *ubounds = buffer + dimlen;
   double *restrict levels;
@@ -1524,15 +1525,17 @@ cdf_def_zaxis_hybrid_cf(stream_t *streamptr, int type, int *ncvaridp, int zaxisI
       streamptr->ncmode = 2;
     }
 
-  if (p0varid != CDI_UNDEFID) cdf_put_var_double(fileID, p0varid, &p0value);
-
   struct cdfPostDefActionList *delayed = NULL;
+
+  if (p0varid != CDI_UNDEFID)
+    cdfPostDefActionAddPutVal(&delayed, fileID, p0varid, &p0value, (void (*)(void *))(void (*)(void)) memFree);
+
   cdfPostDefActionAddPutVal(&delayed, fileID, ncvarid, levels,
                             hasLevels ? (void (*)(void *))(void (*)(void)) memFree : cdfDelayedPutVarDeepCleanup);
 
   if (ncbvarid != CDI_UNDEFID)
     {
-      double *restrict zbounds = (double *) Malloc(2 * dimlen * sizeof(*zbounds));
+      double *zbounds = (double *) Malloc(2 * dimlen * sizeof(*zbounds));
       for (size_t i = 0; i < dimlen; ++i)
         {
           zbounds[2 * i] = lbounds[i];
@@ -1722,7 +1725,7 @@ cdfDefZaxis(stream_t *streamptr, int zaxisID)
   int length = CDI_MAX_NAME;
   cdiInqKeyString(zaxisID, CDI_GLOBAL, CDI_KEY_NAME, axisname, &length);
   int zaxisindex = vlistZaxisIndex(vlistID, zaxisID);
-  int nzaxis = vlistNzaxis(vlistID);
+  int nzaxis = vlistNumZaxis(vlistID);
   int fileID = streamptr->fileID;
 
   checkZaxisName(axisname, fileID, vlistID, zaxisID, nzaxis);
@@ -1801,8 +1804,8 @@ cdfDefZaxis(stream_t *streamptr, int zaxisID)
                     cdf_put_att_text(fileID, ncvarid, "bounds", axisnameLen + sizeof(bndsName), axisname);
                   }
                   {
-                    double *restrict zbounds = (double *) Malloc(4 * dimlen * sizeof(*zbounds)),
-                                     *restrict lbounds = zbounds + 2 * dimlen, *restrict ubounds = zbounds + 3 * dimlen;
+                    double *zbounds = (double *) Malloc(4 * dimlen * sizeof(*zbounds)), *lbounds = zbounds + 2 * dimlen,
+                           *ubounds = zbounds + 3 * dimlen;
                     zaxisInqLbounds(zaxisID, lbounds);
                     zaxisInqUbounds(zaxisID, ubounds);
                     for (size_t i = 0; i < dimlen; ++i)
@@ -1874,6 +1877,7 @@ cdf_def_mapping(stream_t *streamptr, int gridID)
   return delayed;
 }
 
+#ifndef USE_MPI
 static void
 cdfDefCharacter(stream_t *streamptr, int gridID, int gridIndex, int cdiAxisID, int strlen)
 {
@@ -1881,7 +1885,7 @@ cdfDefCharacter(stream_t *streamptr, int gridID, int gridIndex, int cdiAxisID, i
 
   bool isXaxis = (cdiAxisID == CDI_XAXIS);
 
-  size_t dimlen = isXaxis ? gridInqXsize(gridID) : gridInqYsize(gridID);
+  SizeType dimlen = isXaxis ? gridInqXsize(gridID) : gridInqYsize(gridID);
   ncgrid_t *ncgrid = streamptr->ncgrid;
 
   // Check for all grids up to gridIndex whether it already is defined
@@ -1892,9 +1896,9 @@ cdfDefCharacter(stream_t *streamptr, int gridID, int gridIndex, int cdiAxisID, i
       int gridtype0 = gridInqType(gridID0);
       if (gridtype0 == GRID_CHARXY)
         {
-          if (gridInqXIsc(gridID0) == strlen && (size_t) gridInqXsize(gridID0) == dimlen)
+          if (gridInqXIsc(gridID0) == strlen && gridInqXsize(gridID0) == dimlen)
             return;
-          else if (gridInqYIsc(gridID0) == strlen && (size_t) gridInqYsize(gridID0) == dimlen)
+          else if (gridInqYIsc(gridID0) == strlen && gridInqYsize(gridID0) == dimlen)
             return;
         }
     }
@@ -1913,8 +1917,8 @@ cdfDefCharacter(stream_t *streamptr, int gridID, int gridIndex, int cdiAxisID, i
       memcpy(dimname, "region", 7);
       dimname[6] = 0;
     }
-  int dimID = checkDimName(fileID, dimlen, dimname);
-  if (dimID == CDI_UNDEFID) cdf_def_dim(fileID, dimname, dimlen, &dimID);
+  int dimID = checkDimName(fileID, (size_t) dimlen, dimname);
+  if (dimID == CDI_UNDEFID) cdf_def_dim(fileID, dimname, (size_t) dimlen, &dimID);
 
   // Define strlength dim
 
@@ -1929,8 +1933,8 @@ cdfDefCharacter(stream_t *streamptr, int gridID, int gridIndex, int cdiAxisID, i
   dimIDs[1] = strlenID;
 
   char axisname[CDI_MAX_NAME];
-  char **cvals = (char **) Malloc(dimlen * sizeof(char *));
-  for (size_t i = 0; i < dimlen; i++) cvals[i] = (char *) Malloc(strlen * sizeof(char));
+  char **cvals = (char **) Malloc((size_t) dimlen * sizeof(char *));
+  for (size_t i = 0; i < (size_t) dimlen; i++) cvals[i] = (char *) Malloc(strlen * sizeof(char));
   int ncaxisid;
   length = CDI_MAX_NAME;
   cdiInqKeyString(gridID, cdiAxisID, CDI_KEY_NAME, axisname, &length);
@@ -1947,7 +1951,7 @@ cdfDefCharacter(stream_t *streamptr, int gridID, int gridIndex, int cdiAxisID, i
   // Write Var
 
   size_t start[2] = { 0, 0 }, count[2] = { 1, strlen };
-  for (size_t i = 0; i < dimlen; i++)
+  for (size_t i = 0; i < (size_t) dimlen; i++)
     {
       start[0] = i;
       (void) nc_put_vara_text(fileID, ncaxisid, start, count, cvals[i]);
@@ -1959,6 +1963,7 @@ cdfDefCharacter(stream_t *streamptr, int gridID, int gridIndex, int cdiAxisID, i
 
   streamptr->ncmode = 2;
 }
+#endif
 
 static void
 cdfDefReducedGrid(stream_t *streamptr, int gridID, int gridIndex)
@@ -1968,10 +1973,10 @@ cdfDefReducedGrid(stream_t *streamptr, int gridID, int gridIndex)
   ncgrid[gridIndex].gridID = gridID;
 
   {
-    size_t dimlen = gridInqSize(gridID);
+    SizeType dimlen = gridInqSize(gridID);
 
-    struct idSearch search = cdfSearchIDBySize(0, (size_t) gridIndex, ncgrid, CDF_DIMID_X, GRID_GAUSSIAN_REDUCED, (int) dimlen,
-                                               gridInqType, gridInqSize);
+    struct idSearch search
+        = cdfSearchIDBySize(0, (size_t) gridIndex, ncgrid, CDF_DIMID_X, GRID_GAUSSIAN_REDUCED, dimlen, gridInqType, gridInqSize);
     int iz = search.numNonMatching;
     int dimID = search.foundID;
 
@@ -1990,7 +1995,7 @@ cdfDefReducedGrid(stream_t *streamptr, int gridID, int gridIndex)
             cdf_redef(fileID);
           }
 
-        cdf_def_dim(fileID, axisname, dimlen, &dimID);
+        cdf_def_dim(fileID, axisname, (size_t) dimlen, &dimID);
 
         if (switchNCMode)
           {
@@ -2003,10 +2008,10 @@ cdfDefReducedGrid(stream_t *streamptr, int gridID, int gridIndex)
   }
 
   {
-    size_t dimlen = gridInqYsize(gridID);
+    SizeType dimlen = gridInqYsize(gridID);
 
-    struct idSearch search = cdfSearchIDBySize(0, (size_t) gridIndex, ncgrid, CDF_DIMID_RP, GRID_GAUSSIAN_REDUCED, (int) dimlen,
-                                               gridInqType, gridInqSize);
+    struct idSearch search
+        = cdfSearchIDBySize(0, (size_t) gridIndex, ncgrid, CDF_DIMID_RP, GRID_GAUSSIAN_REDUCED, dimlen, gridInqType, gridInqSize);
     int iz = search.numNonMatching;
     int dimID = search.foundID;
 
@@ -2020,7 +2025,7 @@ cdfDefReducedGrid(stream_t *streamptr, int gridID, int gridIndex)
 
         if (streamptr->ncmode == 2) cdf_redef(fileID);
 
-        cdf_def_dim(fileID, axisname, dimlen, &dimID);
+        cdf_def_dim(fileID, axisname, (size_t) dimlen, &dimID);
 
         int ncvarid = CDI_UNDEFID;
         cdf_def_var(fileID, axisname, NC_INT, 1, &dimID, &ncvarid);
@@ -2028,7 +2033,7 @@ cdfDefReducedGrid(stream_t *streamptr, int gridID, int gridIndex)
         cdf_enddef(fileID, streamptr->self);
         streamptr->ncmode = 2;
 
-        int *reducedPoints = (int *) Malloc(dimlen * sizeof(int));
+        int *reducedPoints = (int *) Malloc((size_t) dimlen * sizeof(int));
         gridInqReducedPoints(gridID, reducedPoints);
         cdf_put_var_int(fileID, ncvarid, reducedPoints);
         Free(reducedPoints);
@@ -2046,19 +2051,19 @@ cdf_define_generic_dim(stream_t *streamptr, int gridID, int gridIndex)
   ncgrid_t *ncgrid = streamptr->ncgrid;
   int dimID = CDI_UNDEFID;
 
-  size_t dimlen = gridInqSize(gridID);
+  SizeType dimlen = gridInqSize(gridID);
 
   if (gridInqYsize(gridID) == 0)
     {
       struct idSearch search
-          = cdfSearchIDBySize(0, (size_t) gridIndex, ncgrid, CDF_DIMID_X, GRID_GENERIC, (int) dimlen, gridInqType, gridInqSize);
+          = cdfSearchIDBySize(0, (size_t) gridIndex, ncgrid, CDF_DIMID_X, GRID_GENERIC, dimlen, gridInqType, gridInqSize);
       dimID = search.foundID;
     }
 
   if (gridInqXsize(gridID) == 0)
     {
       struct idSearch search
-          = cdfSearchIDBySize(0, (size_t) gridIndex, ncgrid, CDF_DIMID_Y, GRID_GENERIC, (int) dimlen, gridInqType, gridInqSize);
+          = cdfSearchIDBySize(0, (size_t) gridIndex, ncgrid, CDF_DIMID_Y, GRID_GENERIC, dimlen, gridInqType, gridInqSize);
       dimID = search.foundID;
     }
 
@@ -2070,7 +2075,7 @@ cdf_define_generic_dim(stream_t *streamptr, int gridID, int gridIndex)
       cdiInqKeyString(gridID, CDI_GLOBAL, CDI_KEY_DIMNAME, dimname, &length);
       if (dimname[0] == 0) strcpy(dimname, "gsize");
 
-      dimID = checkDimName(fileID, dimlen, dimname);
+      dimID = checkDimName(fileID, (size_t) dimlen, dimname);
 
       if (dimID == CDI_UNDEFID)
         {
@@ -2081,7 +2086,7 @@ cdf_define_generic_dim(stream_t *streamptr, int gridID, int gridIndex)
               cdf_redef(fileID);
             }
 
-          cdf_def_dim(fileID, dimname, dimlen, &dimID);
+          cdf_def_dim(fileID, dimname, (size_t) dimlen, &dimID);
 
           if (switchNCMode)
             {
@@ -2103,7 +2108,7 @@ cdf_define_grid(stream_t *streamptr, int gridID, int gridIndex)
   if (streamptr->ncgrid[gridIndex].ncIDs[CDF_DIMID_X] != CDI_UNDEFID) return delayed;
 
   int gridtype = gridInqType(gridID);
-  size_t size = gridInqSize(gridID);
+  SizeType size = gridInqSize(gridID);
 
   if (CDI_Debug) Message("gridtype = %d  size = %zu", gridtype, size);
 
@@ -2116,8 +2121,8 @@ cdf_define_grid(stream_t *streamptr, int gridID, int gridIndex)
   if (gridtype == GRID_GAUSSIAN || gridtype == GRID_LONLAT || gridtype == GRID_PROJECTION)
     {
       int ndims = !(gridtype == GRID_LONLAT && size == 1 && !gridInqHasDims(gridID));
-      size_t xsize = gridInqXsize(gridID);
-      size_t ysize = gridInqYsize(gridID);
+      SizeType xsize = gridInqXsize(gridID);
+      SizeType ysize = gridInqYsize(gridID);
 
       if (xsize)
         {
@@ -2141,15 +2146,15 @@ cdf_define_grid(stream_t *streamptr, int gridID, int gridIndex)
     }
   else if (gridtype == GRID_GENERIC)
     {
-      if (size == 1 && gridInqXsize(gridID) == 0 && gridInqYsize(gridID) == 0)
+      SizeType xsize = gridInqXsize(gridID);
+      SizeType ysize = gridInqYsize(gridID);
+      if (size == 1 && xsize == 0 && ysize == 0)
         {
           // no grid information
           streamptr->ncgrid[gridIndex].gridID = gridID;
         }
       else
         {
-          size_t xsize = gridInqXsize(gridID);
-          size_t ysize = gridInqYsize(gridID);
 
           if (xsize > 0)
             {
@@ -2200,6 +2205,7 @@ cdf_define_grid(stream_t *streamptr, int gridID, int gridIndex)
       cdfDefTrajLon(streamptr, gridID, gridIndex);
       cdfDefTrajLat(streamptr, gridID, gridIndex);
     }
+#ifndef USE_MPI
   else if (gridtype == GRID_CHARXY)
     {
       int strlen = 0;
@@ -2221,6 +2227,7 @@ cdf_define_grid(stream_t *streamptr, int gridID, int gridIndex)
           Free(ydelayed);
         }
     }
+#endif
   else
     {
       Error("Unsupported grid type: %s", gridNamePtr(gridtype));
@@ -2236,12 +2243,12 @@ cdfDefCoordinateVars(stream_t *streamptr)
 
   if (vlistHasTime(vlistID)) cdfDefTime(streamptr);
 
-  int ngrids = vlistNgrids(vlistID);
+  int ngrids = vlistNumGrids(vlistID);
   if (2 * ngrids > MAX_GRIDS_PS) Error("Internal problem! Too many grids per stream (max=%d)\n", MAX_GRIDS_PS);
 
   struct cdfPostDefActionList *delayed = NULL;
 
-  ncgrid_t *restrict ncgrid = streamptr->ncgrid;
+  ncgrid_t *ncgrid = streamptr->ncgrid;
   for (int index = 0; index < 2 * ngrids; ++index)
     {
       ncgrid[index].gridID = CDI_UNDEFID;
@@ -2270,7 +2277,7 @@ cdfDefCoordinateVars(stream_t *streamptr)
       }
   }
 
-  int nzaxis = vlistNzaxis(vlistID);
+  int nzaxis = vlistNumZaxis(vlistID);
   for (int index = 0; index < nzaxis; ++index)
     {
       int zaxisID = vlistZaxis(vlistID, index);
