@@ -402,7 +402,7 @@ after_readTimestep(void *arg)
           auto level = (int) zaxisInqLevel(zaxisID, levelID);
           for (int i = 0; i < globs->NumLevelRequest; ++i)
             {
-              if (IS_EQUAL(globs->LevelRequest[i], level))
+              if (is_equal(globs->LevelRequest[i], level))
                 {
                   levelOffset = i;
                   break;
@@ -747,7 +747,7 @@ after_setLevel(AfterControl &globs)
           if (globs.Verbose) fprintf(stdout, " No level detected\n");
           checkLevel = false;
         }
-      else if (globs.NumLevelRequest == 1 && IS_EQUAL(globs.LevelRequest[0], 0))
+      else if (globs.NumLevelRequest == 1 && is_equal(globs.LevelRequest[0], 0))
         {
           if (globs.Verbose) fprintf(stdout, " No level selected\n");
           globs.NumLevelRequest = 0;
@@ -776,7 +776,7 @@ after_setLevel(AfterControl &globs)
         {
           level = globs.LevelRequest[k];
           for (int l = k + 1; l < globs.NumLevelRequest; ++l)
-            if (removeLevel[l] == false && IS_EQUAL(level, globs.LevelRequest[l]))
+            if (removeLevel[l] == false && is_equal(level, globs.LevelRequest[l]))
               {
                 if (globs.Verbose) fprintf(stdout, "  Level %2d = %13.4f double request\n", l + 1, globs.LevelRequest[l]);
                 removeLevel[l] = true;
@@ -799,7 +799,7 @@ after_setLevel(AfterControl &globs)
               level = globs.LevelRequest[k];
               found = false;
               for (int l = 0; l < globs.NumLevelFound; ++l)
-                if (IS_EQUAL(level, LevelFound[l])) found = true;
+                if (is_equal(level, LevelFound[l])) found = true;
 
               if (!found)
                 {
@@ -1209,7 +1209,7 @@ after_parini(AfterControl &globs, struct Variable *vars)
 
   scan_darray(namelist, "level", globs.LevelRequest, MaxLevel, &globs.NumLevelRequest);
   if (globs.NumLevelRequest == 1)
-    if (IS_EQUAL(globs.LevelRequest[0], -1)) globs.NumLevelRequest = 0;
+    if (is_equal(globs.LevelRequest[0], -1)) globs.NumLevelRequest = 0;
 
   if (globs.Verbose) lprintf(stdout);
 
@@ -1235,9 +1235,9 @@ after_dimcalc(AfterControl &globs)
 
   globs.Waves = globs.Truncation + 1;
   globs.Fouriers = globs.Waves * 2;
-  globs.DimSP = (globs.Truncation + 1) * (globs.Truncation + 2);
-  globs.DimFC = globs.Latitudes * globs.Fouriers;
-  globs.DimGP = globs.Latitudes * globs.Longitudes;
+  globs.DimSP = ((long) globs.Truncation + 1) * ((long) globs.Truncation + 2);
+  globs.DimFC = (long) globs.Latitudes * (long) globs.Fouriers;
+  globs.DimGP = (long) globs.Latitudes * (long) globs.Longitudes;
   globs.Dim3GP = globs.NumLevel * globs.DimGP;
   globs.Dim3FC = globs.NumLevel * globs.DimFC;
   globs.Dim3SP = globs.NumLevel * globs.DimSP;
@@ -1692,7 +1692,7 @@ after_processing(AfterControl &globs, struct Variable *vars)
             exit(1);
           }
 
-        if (!globs.unitsel && globs.Type >= 20 && globs.NumLevelRequest > 1 && IS_EQUAL(globs.LevelRequest[i], 0))
+        if (!globs.unitsel && globs.Type >= 20 && globs.NumLevelRequest > 1 && is_equal(globs.LevelRequest[i], 0))
           {
             fprintf(stderr, "\n Level %9.2f illegal for Type %d\n", globs.LevelRequest[i], globs.Type);
             exit(1);
