@@ -276,24 +276,20 @@ coll_cells_reg2d(const Field &field1, Field &field2, const CollgridInfo &collgri
       auto offset1 = j * nx;
       auto offset2 = collgridInfo.offset + j * nlon;
 
-      if (field1.memType == MemType::Float)
-        for (size_t i = 0; i < nx; ++i) field2.vec_f[offset2 + i] = field1.vec_f[offset1 + i];
-      else
-        for (size_t i = 0; i < nx; ++i) field2.vec_d[offset2 + i] = field1.vec_d[offset1 + i];
+      auto func = [&](const auto &v1, auto &v2, auto n) {
+        for (size_t i = 0; i < nx; ++i) { v2[offset2 + i] = v1[offset1 + i]; }
+      };
+      field_operation2(func, field1, field2);
     }
 }
 */
 static void
 collect_cells(const Field &field1, Field &field2, const std::vector<long> &cellIndex)
 {
-  if (field1.memType != field2.memType) cdo_abort("Interal error, memType of field1 and field2 differ!");
-
-  auto patchSize = field1.size;
-
-  if (field1.memType == MemType::Float)
-    for (size_t i = 0; i < patchSize; ++i) field2.vec_f[cellIndex[i]] = field1.vec_f[i];
-  else
-    for (size_t i = 0; i < patchSize; ++i) field2.vec_d[cellIndex[i]] = field1.vec_d[i];
+  auto func = [&](const auto &v1, auto &v2, auto n) {
+    for (size_t i = 0; i < n; ++i) { v2[cellIndex[i]] = v1[i]; }
+  };
+  field_operation2(func, field1, field2, field1.size);
 }
 
 static std::vector<int>
