@@ -91,9 +91,6 @@ private:
   int taxisID2;
   int calendar;
   VarList varList1;
-  FieldVector2D varsData;
-
-  Field field1, field2;
   bool ldivdt;
 
 public:
@@ -120,12 +117,15 @@ public:
 
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
-
-    field2D_init(varsData, vlistID1, FIELD_VEC | FIELD_NAT);
   }
+
   void
   run() override
   {
+    Field field1, field2;
+    FieldVector2D varsData;
+    field2D_init(varsData, varList1, FIELD_VEC | FIELD_NAT);
+
     int tsID = 0;
     auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
 
