@@ -107,7 +107,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     GHEIGHT_FULL = module.get_id("gheight");
     GHEIGHT_HALF = module.get_id("gheight_half");
@@ -138,24 +138,24 @@ public:
 
     if (zaxisID_ML == -1) cdo_abort("No 3D variable with hybrid sigma pressure coordinate found!");
 
-    varList_init(varList1, vlistID1);
-    varListSetUniqueMemtype(varList1);
+    varList1 = VarList(vlistID1);
+    varList_set_unique_memtype(varList1);
 
-    auto nvars = vlistNvars(vlistID1);
+    auto numVars = varList1.numVars();
 
-    varIDs = search_varIDs(varList1, vlistID1, numFullLevels);
+    varIDs = varList_search_varIDs(varList1, numFullLevels);
 
     if (Options::cdoVerbose)
       {
         cdo_print("Found:");
         // clang-format off
-        if (-1 != varIDs.humID)     cdo_print("  %s -> %s", var_stdname(specific_humidity), varList1[varIDs.humID].name);
-        if (-1 != varIDs.tempID)    cdo_print("  %s -> %s", var_stdname(air_temperature), varList1[varIDs.tempID].name);
-        if (-1 != varIDs.psID)      cdo_print("  %s -> %s", var_stdname(surface_air_pressure), varList1[varIDs.psID].name);
-        if (-1 != varIDs.lnpsID)    cdo_print("  LOG(%s) -> %s", var_stdname(surface_air_pressure), varList1[varIDs.lnpsID].name);
-        if (-1 != varIDs.sgeopotID) cdo_print("  %s -> %s", var_stdname(surface_geopotential), varList1[varIDs.sgeopotID].name);
-        if (-1 != varIDs.geopotID)  cdo_print("  %s -> %s", var_stdname(geopotential), varList1[varIDs.geopotID].name);
-        if (-1 != varIDs.gheightID) cdo_print("  %s -> %s", var_stdname(geopotential_height), varList1[varIDs.gheightID].name);
+        if (-1 != varIDs.humID)     cdo_print("  %s -> %s", var_stdname(specific_humidity), varList1.vars[varIDs.humID].name);
+        if (-1 != varIDs.tempID)    cdo_print("  %s -> %s", var_stdname(air_temperature), varList1.vars[varIDs.tempID].name);
+        if (-1 != varIDs.psID)      cdo_print("  %s -> %s", var_stdname(surface_air_pressure), varList1.vars[varIDs.psID].name);
+        if (-1 != varIDs.lnpsID)    cdo_print("  LOG(%s) -> %s", var_stdname(surface_air_pressure), varList1.vars[varIDs.lnpsID].name);
+        if (-1 != varIDs.sgeopotID) cdo_print("  %s -> %s", var_stdname(surface_geopotential), varList1.vars[varIDs.sgeopotID].name);
+        if (-1 != varIDs.geopotID)  cdo_print("  %s -> %s", var_stdname(geopotential), varList1.vars[varIDs.geopotID].name);
+        if (-1 != varIDs.gheightID) cdo_print("  %s -> %s", var_stdname(geopotential_height), varList1.vars[varIDs.gheightID].name);
         // clang-format on
       }
 
@@ -164,13 +164,12 @@ public:
 
     if (varIDs.tempID == -1) cdo_abort("%s not found!", var_stdname(air_temperature));
 
-    for (int varID = 0; varID < nvars; ++varID)
+    for (int varID = 0; varID < numVars; ++varID)
       {
         if (operatorID == SEALEVELPRESSURE) varIDs.humID = -1;
 
-        const auto &var = varList1[varID];
-        if (var.gridType == GRID_SPECTRAL && var.zaxisType == ZAXIS_HYBRID)
-          cdo_abort("Spectral data on model level unsupported!");
+        const auto &var = varList1.vars[varID];
+        if (var.gridType == GRID_SPECTRAL && var.zaxisType == ZAXIS_HYBRID) cdo_abort("Spectral data on model level unsupported!");
 
         if (var.gridType == GRID_SPECTRAL) cdo_abort("Spectral data unsupported!");
       }
@@ -271,7 +270,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -321,13 +320,14 @@ public:
             check_range_var2d(tsID + 1, sgeopot, MIN_FIS, MAX_FIS, "Orography");
           }
 
-        check_range_var3d(tsID + 1, varList1[varIDs.tempID].nlevels, gridsize, temp, MIN_T, MAX_T, "Temperature");
+        check_range_var3d(tsID + 1, varList1.vars[varIDs.tempID].nlevels, gridsize, temp, MIN_T, MAX_T, "Temperature");
 
-        if (varIDs.humID != -1) check_range_var3d(tsID + 1, varList1[varIDs.humID].nlevels, gridsize, hum, -0.1, MAX_Q, "Humidity");
+        if (varIDs.humID != -1)
+          check_range_var3d(tsID + 1, varList1.vars[varIDs.humID].nlevels, gridsize, hum, -0.1, MAX_Q, "Humidity");
 
         if (operatorID == GHEIGHT_FULL || operatorID == GHEIGHT_HALF)
           {
-            vct_to_hybrid_pressure((double *) nullptr, halfPress.data(), vct.data(), ps.data(), numFullLevels, gridsize);
+            vct_to_hybrid_pressure((double *) nullptr, halfPress.data(), vct, ps.data(), numFullLevels, gridsize);
             array_copy(gridsize, sgeopot.data(), gheight.data() + gridsize * numFullLevels);
             if (operatorID == GHEIGHT_FULL)
               geopot_height_full(gheight.data(), temp.data(), hum.data(), halfPress.data(), gridsize, numFullLevels);
@@ -344,7 +344,7 @@ public:
           }
         else if (operatorID == SEALEVELPRESSURE)
           {
-            vct_to_hybrid_pressure(fullPress.data(), halfPress.data(), vct.data(), ps.data(), numFullLevels, gridsize);
+            vct_to_hybrid_pressure(fullPress.data(), halfPress.data(), vct, ps.data(), numFullLevels, gridsize);
 
             extrapolate_P(sealevelpressure.data(), &halfPress[gridsize * numFullLevels], &fullPress[gridsize * (numFullLevels - 1)],
                           sgeopot.data(), &temp[gridsize * (numFullLevels - 1)], gridsize);
@@ -360,7 +360,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
