@@ -51,7 +51,7 @@ print_location_LL(int operfunc, const CdoVar &var, int levelID, double sglval, c
       T value = sglval;
       for (size_t ij = 0; ij < var.gridsize; ++ij)
         {
-          if (dbl_is_equal(v[ij], value))
+          if (fp_is_equal(v[ij], value))
             {
               auto j = ij / nlon;
               auto i = ij - j * nlon;
@@ -74,16 +74,15 @@ print_location_LL(int operfunc, const CdoVar &var, int levelID, double sglval, c
 static void
 print_location_LL(int operfunc, const CdoVar &var, int levelID, double sglval, const Field &field, CdiDateTime vDateTime)
 {
-  if (field.memType == MemType::Float)
-    print_location_LL(operfunc, var, levelID, sglval, field.vec_f, vDateTime);
-  else
-    print_location_LL(operfunc, var, levelID, sglval, field.vec_d, vDateTime);
+  auto func = [&](const auto &v) { print_location_LL(operfunc, var, levelID, sglval, v, vDateTime); };
+  field_operation(func, field);
 }
 
 template <typename T>
 static void
-field_mul_weights(Varray<T> &v1, const Varray<double> &v2, size_t numMissVals, T missval)
+field_mul_weights(Varray<T> &v1, const Varray<double> &v2, size_t numMissVals, double mv)
 {
+  T missval = mv;
   assert(v1.size() > 0);
   assert(v2.size() == v1.size());
 
@@ -91,7 +90,7 @@ field_mul_weights(Varray<T> &v1, const Varray<double> &v2, size_t numMissVals, T
   if (numMissVals)
     {
       for (size_t i = 0; i < gridSize; ++i)
-        if (dbl_is_not_equal(v1[i], missval)) v1[i] *= v2[i];
+        if (fp_is_not_equal(v1[i], missval)) v1[i] *= v2[i];
     }
   else
     {
@@ -102,10 +101,8 @@ field_mul_weights(Varray<T> &v1, const Varray<double> &v2, size_t numMissVals, T
 static void
 field_mul_weights(Field &field)
 {
-  if (field.memType == MemType::Float)
-    field_mul_weights(field.vec_f, field.weightv, field.numMissVals, (float) field.missval);
-  else
-    field_mul_weights(field.vec_d, field.weightv, field.numMissVals, field.missval);
+  auto func = [&](auto &v, const auto &w, auto numMissVals, double missval) { field_mul_weights(v, w, numMissVals, missval); };
+  field_operation(func, field, field.weightv, field.numMissVals, field.missval);
 }
 
 static void
@@ -163,7 +160,7 @@ fldstatGetParameter(bool &useWeights)
   auto pargc = cdo_operator_argc();
   if (pargc)
     {
-      auto pargv = cdo_get_oper_argv();
+      const auto &pargv = cdo_get_oper_argv();
 
       KVList kvlist;
       kvlist.name = cdo_module_name();
@@ -186,7 +183,7 @@ fldstatGetParameter(bool &useWeights)
 }
 
 static int
-get_gridcell_weights(Field &field, bool useWeights, bool doPrintWarning, int ngrids, std::string &varName)
+get_gridcell_weights(Field &field, bool useWeights, bool doPrintWarning, int ngrids, const std::string &varName)
 {
   auto gridSize = field.size;
   field.weightv.resize(gridSize);
@@ -322,7 +319,7 @@ public:
   {
     Field field;
     auto numSteps = varList1.numSteps();
-    cdo::Progress progress;
+    cdo::Progress progress(get_id());
 
     int lastgrid = -1;
     int tsID = 0;
@@ -359,7 +356,7 @@ public:
 
             if (Options::cdoVerbose && isMinMaxFunc) { print_location_LL(operfunc, var, levelID, singleValue, field, vDateTime); }
 
-            size_t numMissVals = dbl_is_equal(singleValue, field.missval);
+            size_t numMissVals = fp_is_equal(singleValue, field.missval);
 
             cdo_def_record(streamID2, varID, levelID);
             cdo_write_record(streamID2, &singleValue, numMissVals);
