@@ -13,7 +13,6 @@
 #include <cdi.h>
 
 #include "cdo_options.h"
-#include "cdo_vlist.h"
 #include "process_int.h"
 #include "param_conversion.h"
 
@@ -33,6 +32,7 @@ public:
     .constraints = { 1, 1, NoRestriction },
   };
   inline static RegisterEntry<Histogram> registration = RegisterEntry<Histogram>(module);
+
   int HISTCOUNT, HISTSUM, HISTMEAN, HISTFREQ;
 
 private:
@@ -47,7 +47,8 @@ private:
   Varray2D<double> vartcount;
 
   Varray<double> array;
-  VarList varList1, varList2;
+  VarList varList1;
+  VarList varList2;
 
   int nbins;
 
@@ -57,15 +58,12 @@ private:
 
 public:
   void
-  init()
+  init() override
   {
-
-    // clang-format off
-HISTCOUNT = module.get_id("histcount");
-HISTSUM = module.get_id("histsum");
-HISTMEAN = module.get_id("histmean");
-HISTFREQ = module.get_id("histfreq");
-    // clang-format on
+    HISTCOUNT = module.get_id("histcount");
+    HISTSUM = module.get_id("histsum");
+    HISTMEAN = module.get_id("histmean");
+    HISTFREQ = module.get_id("histfreq");
 
     (void) (HISTSUM);  // unused
 
@@ -73,7 +71,7 @@ HISTFREQ = module.get_id("histfreq");
 
     operator_input_arg("bins");
 
-    fltarr = cdo_argv_to_flt(cdo_get_oper_argv());
+    fltarr = cdo_argv_to_fltarr(cdo_get_oper_argv());
     nbins = fltarr.size() - 1;
     if (nbins < 1) cdo_abort("Too few arguments!");
 
@@ -84,14 +82,14 @@ HISTFREQ = module.get_id("histfreq");
       }
 
     streamID1 = cdo_open_read(0);
-    const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+    auto vlistID1 = cdo_stream_inq_vlist(streamID1);
 
     taxisID1 = vlistInqTaxis(vlistID1);
 
-    const auto vlistID2 = vlistDuplicate(vlistID1);
+    auto vlistID2 = vlistDuplicate(vlistID1);
 
     /* create zaxis for output bins */
-    const auto zaxisID2 = zaxisCreate(ZAXIS_GENERIC, nbins);
+    auto zaxisID2 = zaxisCreate(ZAXIS_GENERIC, nbins);
 
     zaxisDefLevels(zaxisID2, &fltarr[0]);
     zaxisDefLbounds(zaxisID2, &fltarr[0]);
@@ -102,11 +100,11 @@ HISTFREQ = module.get_id("histfreq");
     cdiDefKeyString(zaxisID2, CDI_GLOBAL, CDI_KEY_UNITS, "level");
 
     /* check zaxis: only 2D fields allowed */
-    const auto nzaxis = vlistNzaxis(vlistID1);
+    auto nzaxis = vlistNumZaxis(vlistID1);
     for (int index = 0; index < nzaxis; ++index)
       {
-        const auto zaxisID = vlistZaxis(vlistID1, index);
-        const auto nlevel = zaxisInqSize(zaxisID);
+        auto zaxisID = vlistZaxis(vlistID1, index);
+        auto nlevel = zaxisInqSize(zaxisID);
         if (nlevel > 1) cdo_abort("Found 3D field with %d levels. Only 2D fields allowed!", nlevel);
         vlistChangeZaxisIndex(vlistID2, index, zaxisID2);
       }
@@ -118,8 +116,8 @@ HISTFREQ = module.get_id("histfreq");
 
     cdo_def_vlist(streamID2, vlistID2);
 
-    varList_init(varList1, vlistID1);
-    varList_init(varList2, vlistID2);
+    varList1 = VarList(vlistID1);
+    varList2 = VarList(vlistID2);
 
     nvars = vlistNvars(vlistID2);
 
@@ -129,22 +127,23 @@ HISTFREQ = module.get_id("histfreq");
 
     for (int varID = 0; varID < nvars; ++varID)
       {
-        const auto gridsize = varList1[varID].gridsize;
+        auto gridsize = varList1.vars[varID].gridsize;
         vardata[varID].resize(nbins * gridsize, 0);
         varcount[varID].resize(nbins * gridsize, 0);
         vartcount[varID].resize(gridsize, 0);
       }
 
-    const auto gridsizemax = vlistGridsizeMax(vlistID1);
+    auto gridsizemax = vlistGridsizeMax(vlistID1);
     array = Varray<double>(gridsizemax);
   }
+
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
       {
-        const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID++);
+        auto nrecs = cdo_stream_inq_timestep(streamID1, tsID++);
         if (nrecs == 0) break;
 
         cdo_taxis_copy_timestep(taxisID2, taxisID1);
@@ -156,20 +155,20 @@ HISTFREQ = module.get_id("histfreq");
             size_t numMissVals;
             cdo_read_record(streamID1, array.data(), &numMissVals);
 
-            const auto gridsize = varList1[varID].gridsize;
-            const auto missval = varList1[varID].missval;
+            auto gridsize = varList1.vars[varID].gridsize;
+            auto missval = varList1.vars[varID].missval;
 
             numMissVals = 0;
             for (size_t i = 0; i < gridsize; ++i)
               {
-                if (!DBL_IS_EQUAL(array[i], missval))
+                if (!fp_is_equal(array[i], missval))
                   {
                     vartcount[varID][i] += 1;
                     int index = 0;
                     while (index < nbins)
                       {
-                        const auto offset = gridsize * index;
-                        if (!DBL_IS_EQUAL(vardata[varID][offset + i], missval) && array[i] >= fltarr[index]
+                        auto offset = gridsize * index;
+                        if (!fp_is_equal(vardata[varID][offset + i], missval) && array[i] >= fltarr[index]
                             && array[i] < fltarr[index + 1])
                           {
                             vardata[varID][offset + i] += array[i];
@@ -191,15 +190,15 @@ HISTFREQ = module.get_id("histfreq");
 
     for (int varID = 0; varID < nvars; ++varID)
       {
-        const auto gridsize = varList2[varID].gridsize;
-        const auto missval = varList2[varID].missval;
+        auto gridsize = varList2.vars[varID].gridsize;
+        auto missval = varList2.vars[varID].missval;
 
         // fix missing values
 
         for (int index = 0; index < nbins; ++index)
           {
             size_t numMissVals = 0;
-            const auto offset = gridsize * index;
+            auto offset = gridsize * index;
 
             for (size_t i = 0; i < gridsize; ++i)
               {
@@ -235,7 +234,7 @@ HISTFREQ = module.get_id("histfreq");
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID1);
     cdo_stream_close(streamID2);
