@@ -46,11 +46,8 @@ invert_lon_data(Field &field)
 {
   auto nlon = gridInqXsize(field.grid);
   auto nlat = gridInqYsize(field.grid);
-
-  if (field.memType == MemType::Float)
-    invert_lon_data(field.vec_f, nlon, nlat);
-  else
-    invert_lon_data(field.vec_d, nlon, nlat);
+  auto func = [&](auto &v) { invert_lon_data(v, nlon, nlat); };
+  field_operation(func, field);
 }
 
 template <typename T>
@@ -76,11 +73,8 @@ invert_lat_data(Field &field)
 {
   auto nlon = gridInqXsize(field.grid);
   auto nlat = gridInqYsize(field.grid);
-
-  if (field.memType == MemType::Float)
-    invert_lat_data(field.vec_f, nlon, nlat);
-  else
-    invert_lat_data(field.vec_d, nlon, nlat);
+  auto func = [&](auto &v) { invert_lat_data(v, nlon, nlat); };
+  field_operation(func, field);
 }
 
 static void
