@@ -65,7 +65,7 @@ public:
 
     if (operatorID == SETVALS)
       {
-        fltarr = cdo_argv_to_flt(cdo_get_oper_argv());
+        fltarr = cdo_argv_to_fltarr(cdo_get_oper_argv());
         nvals = fltarr.size();
         if (nvals < 2) cdo_abort("Too few arguments!");
         if (nvals % 2 != 0) cdo_abort("Need pairs of arguments!");
