@@ -19,13 +19,14 @@
 #include "percentiles.h"
 #include "datetime.h"
 #include "field_functions.h"
-#include "cimdOmp.h"
+#include "cdo_omp.h"
 
 template <typename T>
 static size_t
-runpctl(double pn, int ndates, size_t gridsize, Varray<T> &v2, T missval, const FieldVector3D &vars1, int varID, int levelID,
+runpctl(double pn, int ndates, size_t gridsize, Varray<T> &v2, double mv, const FieldVector3D &vars1, int varID, int levelID,
         MemType memType)
 {
+  T missval = mv;
   size_t numMissVals = 0;
   Varray2D<T> array_2D(Threading::ompNumThreads, Varray<T>(ndates));
 
@@ -38,12 +39,13 @@ runpctl(double pn, int ndates, size_t gridsize, Varray<T> &v2, T missval, const
       auto &array = array_2D[ompthID];
 
       int j = 0;
+
       if (memType == MemType::Float)
         {
           for (int inp = 0; inp < ndates; ++inp)
             {
               auto val = vars1[inp][varID][levelID].vec_f[i];
-              if (!dbl_is_equal(val, missval)) array[j++] = val;
+              if (fp_is_not_equal(val, missval)) array[j++] = val;
             }
         }
       else
@@ -51,10 +53,19 @@ runpctl(double pn, int ndates, size_t gridsize, Varray<T> &v2, T missval, const
           for (int inp = 0; inp < ndates; ++inp)
             {
               auto val = vars1[inp][varID][levelID].vec_d[i];
-              if (!dbl_is_equal(val, missval)) array[j++] = val;
+              if (fp_is_not_equal(val, missval)) array[j++] = val;
             }
         }
-
+      /*
+      for (int inp = 0; inp < ndates; ++inp)
+        {
+          auto func = [&](auto &v) {
+            auto val = v[i];
+            if (fp_is_not_equal(val, missval)) array[j++] = val;
+          };
+          field_operation(func, vars1[inp][varID][levelID]);
+        }
+      */
       if (j > 0) { v2[i] = percentile(array.data(), j, pn); }
       else
         {
@@ -69,11 +80,10 @@ runpctl(double pn, int ndates, size_t gridsize, Varray<T> &v2, T missval, const
 static void
 runpctl(double pn, int ndates, Field &field1, const FieldVector3D &vars1, int varID, int levelID)
 {
-  if (field1.memType == MemType::Float)
-    field1.numMissVals
-        = runpctl(pn, ndates, field1.gridsize, field1.vec_f, (float) field1.missval, vars1, varID, levelID, field1.memType);
-  else
-    field1.numMissVals = runpctl(pn, ndates, field1.gridsize, field1.vec_d, field1.missval, vars1, varID, levelID, field1.memType);
+  auto func = [&](auto &v) {
+    field1.numMissVals = runpctl(pn, ndates, field1.gridsize, v, field1.missval, vars1, varID, levelID, field1.memType);
+  };
+  field_operation(func, field1);
 }
 
 class Runpctl : public Process
@@ -89,6 +99,7 @@ public:
     .constraints = { 1, 1, NoRestriction },
   };
   inline static RegisterEntry<Runpctl> registration = RegisterEntry<Runpctl>(module);
+
   CdoStreamID streamID1;
   CdoStreamID streamID2;
   int vlistID1;
@@ -96,19 +107,18 @@ public:
   VarList varList1;
   int taxisID1;
   int taxisID2;
-  FieldVector3D vars1;
+  FieldVector3D varsData1;
 
   DateTimeList dtlist;
   double pn;
   int ndates;
-  int nvars;
-  int maxrecs;
-  std::vector<RecordInfo> recList;
+  int maxRecords;
+  std::vector<RecordInfo> recordList;
   int tsID;
 
 public:
   void
-  init()
+  init() override
   {
     constexpr auto timestatDate{ TimeStat::MEAN };
 
@@ -132,21 +142,16 @@ public:
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
 
-    nvars = vlistNvars(vlistID1);
+    varList1 = VarList(vlistID1);
 
-    maxrecs = vlistNrecs(vlistID1);
-    recList = std::vector<RecordInfo>(maxrecs);
+    maxRecords = varList1.numRecords();
+    recordList = std::vector<RecordInfo>(maxRecords);
 
     dtlist.set_stat(timestatDate);
     dtlist.set_calendar(taxisInqCalendar(taxisID1));
 
-    Varray<float> array_f(ndates);
-    Varray<double> array_d(ndates);
-    vars1 = FieldVector3D(ndates + 1);
-
-    for (int its = 0; its < ndates; its++) fields_from_vlist(vlistID1, vars1[its]);
-
-    varList_init(varList1, vlistID1);
+    varsData1 = FieldVector3D(ndates + 1);
+    for (int its = 0; its < ndates; its++) field2D_init(varsData1[its], varList1);
   }
 
   void
@@ -154,21 +159,20 @@ public:
   {
     dtlist.stat_taxis_def_timestep(taxisID2, ndates);
     cdo_def_timestep(streamID2, otsID);
-    for (int recID = 0; recID < maxrecs; ++recID)
+    for (int recID = 0; recID < maxRecords; ++recID)
       {
-        auto [varID, levelID] = recList[recID].get();
-        if (otsID && varList1[varID].isConstant) continue;
+        auto [varID, levelID] = recordList[recID].get();
+        if (otsID && varList1.vars[varID].isConstant) continue;
 
         cdo_def_record(streamID2, varID, levelID);
-        auto &field1 = vars1[0][varID][levelID];
+        auto &field1 = varsData1[0][varID][levelID];
         cdo_write_record(streamID2, field1);
       }
   }
 
   void
-  run()
+  run() override
   {
-
     for (tsID = 0; tsID < ndates; ++tsID)
       {
         auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
@@ -181,25 +185,26 @@ public:
             int varID, levelID;
             cdo_inq_record(streamID1, &varID, &levelID);
 
-            if (tsID == 0) recList[recID].set(varID, levelID);
+            if (tsID == 0) recordList[recID].set(varID, levelID);
 
-            auto &field = vars1[tsID][varID][levelID];
-            field.init(varList1[varID]);
+            auto &field = varsData1[tsID][varID][levelID];
+            field.init(varList1.vars[varID]);
             cdo_read_record(streamID1, field);
           }
       }
     int otsID = 0;
     while (true)
       {
-        for (int varID = 0; varID < nvars; ++varID)
+        auto numVars = varList1.numVars();
+        for (int varID = 0; varID < numVars; ++varID)
           {
-            if (varList1[varID].isConstant) continue;
+            if (varList1.vars[varID].isConstant) continue;
 
-            auto nlevels = varList1[varID].nlevels;
+            auto nlevels = varList1.vars[varID].nlevels;
             for (int levelID = 0; levelID < nlevels; ++levelID)
               {
-                auto &field1 = vars1[0][varID][levelID];
-                runpctl(pn, ndates, field1, vars1, varID, levelID);
+                auto &field1 = varsData1[0][varID][levelID];
+                runpctl(pn, ndates, field1, varsData1, varID, levelID);
               }
           }
 
@@ -208,8 +213,8 @@ public:
 
         dtlist.shift();
 
-        vars1[ndates] = vars1[0];
-        for (int inp = 0; inp < ndates; ++inp) vars1[inp] = vars1[inp + 1];
+        varsData1[ndates] = varsData1[0];
+        for (int inp = 0; inp < ndates; ++inp) varsData1[inp] = varsData1[inp + 1];
 
         auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
         if (nrecs == 0) break;
@@ -220,7 +225,7 @@ public:
           {
             int varID, levelID;
             cdo_inq_record(streamID1, &varID, &levelID);
-            auto &fieldN = vars1[ndates - 1][varID][levelID];
+            auto &fieldN = varsData1[ndates - 1][varID][levelID];
             cdo_read_record(streamID1, fieldN);
           }
 
@@ -229,7 +234,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
