@@ -18,9 +18,7 @@
 #include "grid_define.h"
 #include "cdo_options.h"
 #include "process_int.h"
-#include "cdo_vlist.h"
 #include "param_conversion.h"
-#include "gridreference.h"
 #include "selboxinfo.h"
 
 static void
@@ -888,9 +886,9 @@ selbox_index_grid(int gridID)
   return selboxInfo;
 }
 
-template <typename T>
+template <typename T1, typename T2>
 static void
-window_box(int nwpv, const T *array1, int gridID, T *array2, long lat1, long lat2, long lon11, long lon12, long lon21, long lon22)
+window_box(int nwpv, const T1 *array1, int gridID, T2 *array2, long lat1, long lat2, long lon11, long lon12, long lon21, long lon22)
 {
   long nlon = gridInqXsize(gridID);
 
@@ -923,17 +921,15 @@ window_box(int nwpv, const T *array1, int gridID, T *array2, long lat1, long lat
 static void
 window_box(const Field &field1, Field &field2, long lat1, long lat2, long lon11, long lon12, long lon21, long lon22)
 {
-  if (field1.memType != field2.memType) cdo_abort("Interal error, memType of field1 and field2 differ!");
-
-  if (field1.memType == MemType::Float)
-    window_box(field1.nwpv, field1.vec_f.data(), field1.grid, field2.vec_f.data(), lat1, lat2, lon11, lon12, lon21, lon22);
-  else
-    window_box(field1.nwpv, field1.vec_d.data(), field1.grid, field2.vec_d.data(), lat1, lat2, lon11, lon12, lon21, lon22);
+  auto func = [&](const auto &v1, auto &v2) {
+    window_box(field1.nwpv, v1.data(), field1.grid, v2.data(), lat1, lat2, lon11, lon12, lon21, lon22);
+  };
+  field_operation2(func, field1, field2);
 }
 
-template <typename T>
+template <typename T1, typename T2>
 static void
-window_cell(int nwpv, const Varray<T> &v1, Varray<T> &v2, long n, const std::vector<long> &index)
+window_cell(int nwpv, const Varray<T1> &v1, Varray<T2> &v2, long n, const std::vector<long> &index)
 {
   if (nwpv == 2)
     {
@@ -955,20 +951,16 @@ window_cell(int nwpv, const Varray<T> &v1, Varray<T> &v2, long n, const std::vec
 void
 window_cell(const Field &field1, Field &field2, const std::vector<long> &cellidx)
 {
-  if (field1.memType != field2.memType) cdo_abort("Interal error, memType of field1 and field2 differ!");
-
-  if (field1.memType == MemType::Float)
-    window_cell(field1.nwpv, field1.vec_f, field2.vec_f, field2.gridsize, cellidx);
-  else
-    window_cell(field1.nwpv, field1.vec_d, field2.vec_d, field2.gridsize, cellidx);
+  auto func = [&](auto &v1, auto &v2) { window_cell(field1.nwpv, v1, v2, field2.gridsize, cellidx); };
+  field_operation2(func, field1, field2);
 }
 
 static std::vector<SelboxInfo>
-get_selboxInfo(int vlistID1, int vlistID2, bool operIndexBox)
+get_selboxInfoList(int vlistID1, int vlistID2, bool operIndexBox)
 {
-  std::vector<SelboxInfo> selboxInfo;
+  std::vector<SelboxInfo> selboxInfoList;
 
-  auto ngrids = vlistNgrids(vlistID1);
+  auto ngrids = vlistNumGrids(vlistID1);
   for (int index = 0; index < ngrids; ++index)
     {
       auto gridID1 = vlistGrid(vlistID1, index);
@@ -984,14 +976,14 @@ get_selboxInfo(int vlistID1, int vlistID2, bool operIndexBox)
       if (isReg2dGeoGrid || projHasGeoCoords || (operIndexBox && (gridtype == GRID_GENERIC || gridtype == GRID_PROJECTION))
           || (!operIndexBox && (gridtype == GRID_UNSTRUCTURED || is_healpix_grid(gridID1))))
         {
-          if (operIndexBox) { selboxInfo.push_back(selbox_index_grid(gridID1)); }
+          if (operIndexBox) { selboxInfoList.push_back(selbox_index_grid(gridID1)); }
           else
             {
-              selboxInfo.push_back((gridtype == GRID_UNSTRUCTURED || is_healpix_grid(gridID1)) ? selbox_cell_grid(gridID1)
-                                                                                               : selbox_lonlat_grid(gridID1));
+              selboxInfoList.push_back((gridtype == GRID_UNSTRUCTURED || is_healpix_grid(gridID1)) ? selbox_cell_grid(gridID1)
+                                                                                                   : selbox_lonlat_grid(gridID1));
             }
 
-          vlistChangeGridIndex(vlistID2, index, selboxInfo.back().gridID2);
+          vlistChangeGridIndex(vlistID2, index, selboxInfoList.back().gridID2);
         }
       else
         {
@@ -1001,7 +993,7 @@ get_selboxInfo(int vlistID1, int vlistID2, bool operIndexBox)
 
   if (Options::cdoVerbose)
     {
-      for (const auto &sb : selboxInfo)
+      for (const auto &sb : selboxInfoList)
         if (sb.gridtype != GRID_UNSTRUCTURED && !is_healpix_grid(sb.gridID1))
           {
             cdo_print("box1 - idx1,idx2,idy1,idy2: %ld,%ld,%ld,%ld", sb.lon21 + 1, sb.lon22 + 1, sb.lat1 + 1, sb.lat2 + 1);
@@ -1009,41 +1001,40 @@ get_selboxInfo(int vlistID1, int vlistID2, bool operIndexBox)
           }
     }
 
-  return selboxInfo;
+  return selboxInfoList;
 }
 
 static std::vector<bool>
-get_processVars(int vlistID1, const std::vector<SelboxInfo> &selboxInfo)
+get_processVars(const VarList &varList, const std::vector<SelboxInfo> &selboxInfoList)
 {
-  auto nvars = vlistNvars(vlistID1);
+  auto numVars = varList.numVars();
 
-  std::vector<bool> processVars(nvars, false);
+  std::vector<bool> processVars(numVars, false);
 
   int varID;
-  for (const auto &sb : selboxInfo)
+  for (const auto &sb : selboxInfoList)
     {
-      for (varID = 0; varID < nvars; ++varID)
-        if (sb.gridID1 == vlistInqVarGrid(vlistID1, varID)) processVars[varID] = true;
+      for (varID = 0; varID < numVars; ++varID)
+        if (sb.gridID1 == varList.vars[varID].gridID) processVars[varID] = true;
     }
 
-  for (varID = 0; varID < nvars; ++varID)
+  for (varID = 0; varID < numVars; ++varID)
     if (processVars[varID]) break;
 
-  if (varID >= nvars) cdo_abort("No processable variable found!");
+  if (varID >= numVars) cdo_abort("No processable variable found!");
 
   return processVars;
 }
 
-static int
-get_grid_index(int gridID, const std::vector<SelboxInfo> &selboxInfo)
+static const SelboxInfo &
+select_selboxInfo(int gridID, const std::vector<SelboxInfo> &selboxInfoList)
 {
-  int ngrids = (int) selboxInfo.size();
-  int index;
-  for (index = 0; index < ngrids; ++index)
-    if (gridID == selboxInfo[index].gridID1) break;
-  if (index == ngrids) cdo_abort("Internal problem, grid not found!");
+  for (const auto &selboxInfo : selboxInfoList)
+    if (gridID == selboxInfo.gridID1) return selboxInfo;
 
-  return index;
+  cdo_abort("Internal problem, grid not found!");
+
+  return selboxInfoList[0];
 }
 
 class Selbox : public Process
@@ -1068,19 +1059,18 @@ public:
   int taxisID1;
   int taxisID2;
 
-  Field field1, field2;
-
-  VarList varList1, varList2;
+  VarList varList1;
+  VarList varList2;
 
   int vlistID2;
   int operatorID;
 
-  std::vector<SelboxInfo> selboxInfo;
+  std::vector<SelboxInfo> selboxInfoList;
   std::vector<bool> processVars;
 
 public:
   void
-  init()
+  init() override
   {
     SELLONLATBOX = module.get_id("sellonlatbox");
     SELINDEXBOX = module.get_id("selindexbox");
@@ -1098,20 +1088,22 @@ public:
     taxisID2 = taxisDuplicate(taxisID1);
     vlistDefTaxis(vlistID2, taxisID2);
 
-    selboxInfo = get_selboxInfo(vlistID1, vlistID2, (operatorID == SELINDEXBOX));
+    selboxInfoList = get_selboxInfoList(vlistID1, vlistID2, (operatorID == SELINDEXBOX));
 
-    processVars = get_processVars(vlistID1, selboxInfo);
+    varList1 = VarList(vlistID1);
+    varList2 = VarList(vlistID2);
 
-    varList_init(varList1, vlistID1);
-    varList_init(varList2, vlistID2);
+    processVars = get_processVars(varList1, selboxInfoList);
 
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
   }
 
   void
-  run()
+  run() override
   {
+    Field field1, field2;
+
     int tsID = 0;
     while (true)
       {
@@ -1123,18 +1115,18 @@ public:
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
-            int varID, levelID;
-            cdo_inq_record(streamID1, &varID, &levelID);
-            field1.init(varList1[varID]);
+            auto [varID, levelID] = cdo_inq_record(streamID1);
+            const auto &var1 = varList1.vars[varID];
+            field1.init(var1);
             cdo_read_record(streamID1, field1);
 
             cdo_def_record(streamID2, varID, levelID);
 
             if (processVars[varID])
               {
-                field2.init(varList2[varID]);
+                field2.init(varList2.vars[varID]);
 
-                const auto &sb = selboxInfo[get_grid_index(varList1[varID].gridID, selboxInfo)];
+                const auto &sb = select_selboxInfo(var1.gridID, selboxInfoList);
 
                 if (operatorID == SELLONLATBOX && (sb.gridtype == GRID_UNSTRUCTURED || is_healpix_grid(sb.gridID1)))
                   window_cell(field1, field2, sb.cellidx);
@@ -1153,7 +1145,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
