@@ -102,7 +102,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     dataIsUnchanged = data_is_unchanged();
 
@@ -126,16 +126,16 @@ public:
 
     cdo_def_vlist(streamID2, vlistID2);
 
-    varList_init(varList1, vlistID1);
+    varList1 = VarList(vlistID1);
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
       {
-        const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+        auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
         if (nrecs == 0) break;
 
         cdo_taxis_copy_timestep(taxisID2, taxisID1);
@@ -150,7 +150,7 @@ public:
             if (dataIsUnchanged) { cdo_copy_record(streamID2, streamID1); }
             else
               {
-                field.init(varList1[varID]);
+                field.init(varList1.vars[varID]);
                 cdo_read_record(streamID1, field);
                 cdo_write_record(streamID2, field);
               }
@@ -161,7 +161,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID1);
     cdo_stream_close(streamID2);
