@@ -52,12 +52,9 @@ public:
 
   int noffset = 0, nskip = 0;
   int ndates;
-  int maxrecs;
 
   double pn;
 
-  std::vector<RecordInfo> recList;
-  FieldVector constFields;
   DateTimeList dtlist;
   Field field1, field2;
   VarList varList1;
@@ -65,9 +62,8 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
-
     operator_input_arg("percentile number, numSets <,noffset <,nskip>>");
 
     auto nargc = cdo_operator_argc();
@@ -91,8 +87,12 @@ public:
 
     vlist_unpack(vlistID4);
 
-    vlist_compare(vlistID1, vlistID2, CmpVlist::All);
-    vlist_compare(vlistID1, vlistID3, CmpVlist::All);
+    varList1 = VarList(vlistID1);
+    VarList varList2(vlistID2);
+    VarList varList3(vlistID3);
+
+    varList_compare(varList1, varList2);
+    varList_compare(varList1, varList3);
 
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = vlistInqTaxis(vlistID2);
@@ -106,27 +106,25 @@ public:
     streamID4 = cdo_open_write(3);
     cdo_def_vlist(streamID4, vlistID4);
 
-    auto ntsteps = vlistNtsteps(vlistID1);
-    auto nvars = vlistNvars(vlistID1);
-
-    maxrecs = vlistNrecs(vlistID1);
-    recList = std::vector<RecordInfo>(maxrecs);
-
-    constFields = FieldVector(maxrecs);
+    auto numVars = varList1.numVars();
+    auto numSteps = varList1.numSteps();
 
     dtlist.set_stat(TimeStat::MEAN);
     dtlist.set_calendar(taxisInqCalendar(taxisID1));
 
-    varList_init(varList1, vlistID1);
+    hset = HistogramSet(numVars, numSteps);
 
-    hset = HistogramSet(nvars, ntsteps);
-
-    for (int varID = 0; varID < nvars; ++varID) hset.createVarLevels(varID, varList1[varID].nlevels, varList1[varID].gridsize);
+    for (const auto &var : varList1.vars) hset.createVarLevels(var.ID, var.nlevels, var.gridsize);
   }
 
   void
-  run()
+  run() override
   {
+    auto maxRecords = varList1.numRecords();
+    std::vector<RecordInfo> recordList(maxRecords);
+
+    FieldVector constFields(maxRecords);
+
     int tsID;
     for (tsID = 0; tsID < noffset; ++tsID)
       {
@@ -135,10 +133,8 @@ public:
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
-            int varID, levelID;
-            cdo_inq_record(streamID1, &varID, &levelID);
-
-            if (tsID == 0) recList[recID].set(varID, levelID);
+            auto [varID, levelID] = cdo_inq_record(streamID1);
+            if (tsID == 0) recordList[recID].set(varID, levelID);
           }
       }
     int otsID = 0;
@@ -165,11 +161,11 @@ public:
           {
             int varID, levelID;
             cdo_inq_record(streamID2, &varID, &levelID);
-            field1.init(varList1[varID]);
+            field1.init(varList1.vars[varID]);
             cdo_read_record(streamID2, field1);
 
             cdo_inq_record(streamID3, &varID, &levelID);
-            field2.init(varList1[varID]);
+            field2.init(varList1.vars[varID]);
             cdo_read_record(streamID3, field2);
 
             hset.defVarLevelBounds(varID, levelID, field1, field2);
@@ -186,19 +182,19 @@ public:
 
               for (int recID = 0; recID < nrecs; ++recID)
                 {
-                  int varID, levelID;
-                  cdo_inq_record(streamID1, &varID, &levelID);
+                  auto [varID, levelID] = cdo_inq_record(streamID1);
 
-                  if (tsID == 0) recList[recID].set(varID, levelID);
+                  if (tsID == 0) recordList[recID].set(varID, levelID);
 
-                  if (tsID == 0 && varList1[varID].isConstant)
+                  const auto &var1 = varList1.vars[varID];
+                  if (tsID == 0 && var1.isConstant)
                     {
-                      constFields[recID].init(varList1[varID]);
+                      constFields[recID].init(var1);
                       cdo_read_record(streamID1, constFields[recID]);
                     }
                   else
                     {
-                      field1.init(varList1[varID]);
+                      field1.init(var1);
                       cdo_read_record(streamID1, field1);
 
                       hset.addVarLevelValues(varID, levelID, field1);
@@ -213,17 +209,18 @@ public:
         dtlist.stat_taxis_def_timestep(taxisID4, numSets);
         cdo_def_timestep(streamID4, otsID);
 
-        for (int recID = 0; recID < maxrecs; ++recID)
+        for (int recID = 0; recID < maxRecords; ++recID)
           {
-            auto [varID, levelID] = recList[recID].get();
-            if (otsID && varList1[varID].isConstant) continue;
+            auto [varID, levelID] = recordList[recID].get();
+            const auto &var1 = varList1.vars[varID];
+            if (otsID && var1.isConstant) continue;
 
             cdo_def_record(streamID4, varID, levelID);
 
-            if (varList1[varID].isConstant) { cdo_write_record(streamID4, constFields[recID]); }
+            if (var1.isConstant) { cdo_write_record(streamID4, constFields[recID]); }
             else
               {
-                field1.init(varList1[varID]);
+                field1.init(var1);
                 hset.getVarLevelPercentiles(field1, varID, levelID, pn);
                 cdo_write_record(streamID4, field1);
               }
@@ -244,7 +241,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID4);
     cdo_stream_close(streamID3);
