@@ -14,9 +14,8 @@
 #include <cdi.h>
 
 #include "process_int.h"
-#include "cdo_vlist.h"
 #include "cdo_options.h"
-#include "cimdOmp.h"
+#include "cdo_omp.h"
 #include "field_functions.h"
 
 class Timsort : public Process
@@ -33,28 +32,26 @@ public:
   };
   inline static RegisterEntry<Timsort> registration = RegisterEntry<Timsort>(module);
 
-  int varID, levelID;
   int nalloc = 0;
 
   CdoStreamID streamID1;
-  int taxisID1;
-  int vlistID1;
-
   CdoStreamID streamID2;
+
+  int taxisID1;
   int taxisID2;
+  int vlistID1;
   int vlistID2;
 
-  int nvars;
+  int numVars;
 
-  VarList varList;
-  FieldVector3D vars;
+  VarList varList1;
+  FieldVector3D varsData;
   std::vector<CdiDateTime> vDateTimes;
 
 public:
   void
-  init()
+  init() override
   {
-
     operator_check_argc(0);
 
     streamID1 = cdo_open_read(0);
@@ -69,13 +66,12 @@ public:
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
 
-    varList_init(varList, vlistID1);
-
-    nvars = vlistNvars(vlistID1);
+    varList1 = VarList(vlistID1);
+    numVars = varList1.numVars();
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -88,18 +84,18 @@ public:
             constexpr int NALLOC_INC = 1024;
             nalloc += NALLOC_INC;
             vDateTimes.resize(nalloc);
-            vars.resize(nalloc);
+            varsData.resize(nalloc);
           }
 
         vDateTimes[tsID] = taxisInqVdatetime(taxisID1);
 
-        fields_from_vlist(vlistID1, vars[tsID]);
+        field2D_init(varsData[tsID], varList1);
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
-            cdo_inq_record(streamID1, &varID, &levelID);
-            auto &field = vars[tsID][varID][levelID];
-            field.init(varList[varID]);
+            auto [varID, levelID] = cdo_inq_record(streamID1);
+            auto &field = varsData[tsID][varID][levelID];
+            field.init(varList1.vars[varID]);
             cdo_read_record(streamID1, field);
           }
 
@@ -110,15 +106,15 @@ public:
 
     std::vector<Field> fields(Threading::ompNumThreads);
 
-    for (varID = 0; varID < nvars; ++varID)
+    for (int varID = 0; varID < numVars; ++varID)
       {
-        const auto &var = varList[varID];
+        const auto &var = varList1.vars[varID];
 
         if (var.isConstant) continue;
 
         auto memType = var.memType;
         auto gridsize = var.gridsize;
-        for (levelID = 0; levelID < var.nlevels; ++levelID)
+        for (int levelID = 0; levelID < var.nlevels; ++levelID)
           {
 #ifdef _OPENMP
 #pragma omp parallel for default(shared) schedule(static)
@@ -131,21 +127,21 @@ public:
                   {
                     auto &v = fields[ompthID].vec_f;
                     v.resize(nts);
-                    for (int t = 0; t < nts; ++t) v[t] = vars[t][varID][levelID].vec_f[i];
+                    for (int t = 0; t < nts; ++t) v[t] = varsData[t][varID][levelID].vec_f[i];
 
                     ranges::sort(v);
 
-                    for (int t = 0; t < nts; ++t) vars[t][varID][levelID].vec_f[i] = v[t];
+                    for (int t = 0; t < nts; ++t) varsData[t][varID][levelID].vec_f[i] = v[t];
                   }
                 else
                   {
                     auto &v = fields[ompthID].vec_d;
                     v.resize(nts);
-                    for (int t = 0; t < nts; ++t) v[t] = vars[t][varID][levelID].vec_d[i];
+                    for (int t = 0; t < nts; ++t) v[t] = varsData[t][varID][levelID].vec_d[i];
 
                     ranges::sort(v);
 
-                    for (int t = 0; t < nts; ++t) vars[t][varID][levelID].vec_d[i] = v[t];
+                    for (int t = 0; t < nts; ++t) varsData[t][varID][levelID].vec_d[i] = v[t];
                   }
               }
           }
@@ -156,12 +152,12 @@ public:
         taxisDefVdatetime(taxisID2, vDateTimes[tsID]);
         cdo_def_timestep(streamID2, tsID);
 
-        for (varID = 0; varID < nvars; ++varID)
+        for (int varID = 0; varID < numVars; ++varID)
           {
-            const auto &var = varList[varID];
-            for (levelID = 0; levelID < var.nlevels; ++levelID)
+            const auto &var = varList1.vars[varID];
+            for (int levelID = 0; levelID < var.nlevels; ++levelID)
               {
-                auto &field = vars[tsID][varID][levelID];
+                auto &field = varsData[tsID][varID][levelID];
                 if (field.hasData())
                   {
                     cdo_def_record(streamID2, varID, levelID);
@@ -173,7 +169,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
