@@ -329,7 +329,7 @@ public:
     Field field;
 
     auto numSteps1 = varList1.numSteps();
-    cdo::Progress progress;
+    cdo::Progress progress(get_id());
 
     int tsID = 0;
     int otsID = 0;
@@ -417,7 +417,7 @@ public:
     CdiDateTime vDateTime0{};
     CdiDateTime vDateTimeN{};
     auto numSteps = varList1.numSteps();
-    cdo::Progress progress;
+    cdo::Progress progress(get_id());
 
     FieldVector3D fields3D(2);
     field2D_init(fields3D[0], varList1, FIELD_VEC | FIELD_NAT);
@@ -504,10 +504,7 @@ public:
   run() override
   {
     auto runAsync = (Options::CDO_Parallel_Read > 0);
-    if (runAsync)
-      run_async();
-    else
-      run_sync();
+    runAsync ? run_async() : run_sync();
   }
 
   void
