@@ -83,8 +83,8 @@ public:
   bool tstepIsEqual = true;
 
   VarList varList1;
+  VarList varList2;
   std::vector<RecordInfo> recordList;
-  size_t gridSizeMax{ 0 };
 
 public:
   void
@@ -106,6 +106,8 @@ public:
     vlistDefTaxis(vlistID2, taxisID2);
 
     varList1 = VarList(vlistID1);
+    varList2 = VarList(vlistID2);
+    for (auto &var : varList2.vars) var.memType = MemType::Double;
 
     maxRecords = varList1.numRecords();
     recordList = std::vector<RecordInfo>(maxRecords);
@@ -118,16 +120,12 @@ public:
 
     cdo_def_vlist(streamID2, vlistID2);
     cdo_def_vlist(streamID3, vlistID2);
-
-    gridSizeMax = vlistGridsizeMax(vlistID1);
   }
 
   void
   write_output(const FieldVector3D &work)
   {
     Field field2, field3;
-    field2.resize(gridSizeMax);
-    field3.resize(gridSizeMax);
 
     cdo_def_timestep(streamID2, 0);
     cdo_def_timestep(streamID3, 0);
@@ -136,19 +134,20 @@ public:
       {
         auto [varID, levelID] = recordList[recID].get();
 
-        const auto &var = varList1.vars[varID];
-        field2.size = var.gridsize;
-        field2.missval = var.missval;
-        field3.size = var.gridsize;
-        field3.missval = var.missval;
+        const auto &var = varList2.vars[varID];
+        field2.init(var);
+        field3.init(var);
 
         calc_trend_param(work, field2, field3, varID, levelID);
 
+        field_num_mv(field2);
+        field_num_mv(field3);
+
         cdo_def_record(streamID2, varID, levelID);
-        cdo_write_record(streamID2, field2.vec_d.data(), field_num_miss(field2));
+        cdo_write_record(streamID2, field2);
 
         cdo_def_record(streamID3, varID, levelID);
-        cdo_write_record(streamID3, field3.vec_d.data(), field_num_miss(field3));
+        cdo_write_record(streamID3, field3);
       }
   }
 
@@ -161,7 +160,7 @@ public:
     CdiDateTime vDateTime{};
     double deltat1 = 0.0;
     auto numSteps = varList1.numSteps();
-    cdo::Progress progress;
+    cdo::Progress progress(get_id());
     Field field1;
 
     FieldVector3D work(numWork);
@@ -218,7 +217,7 @@ public:
     CdiDateTime vDateTime{};
     double deltat1 = 0.0;
     auto numSteps = varList1.numSteps();
-    cdo::Progress progress;
+    cdo::Progress progress(get_id());
 
     FieldVector3D work(numWork);
     for (auto &w : work) field2D_init(w, varList1, FIELD_VEC, 0);
@@ -272,10 +271,7 @@ public:
   run() override
   {
     auto runAsync = (Options::CDO_Parallel_Read > 0);
-    if (runAsync)
-      run_async();
-    else
-      run_sync();
+    runAsync ? run_async() : run_sync();
   }
 
   void
