@@ -15,7 +15,6 @@
 #include <cdi.h>
 
 #include "process_int.h"
-#include "cdo_vlist.h"
 
 #define IS_SURFACE_LEVEL(zaxisID) (zaxisInqType(zaxisID) == ZAXIS_SURFACE && zaxisInqSize(zaxisID) == 1)
 
@@ -27,9 +26,9 @@ add_vars_mv(size_t gridsize, double missval, const Varray<double> &var1, const V
   for (size_t i = 0; i < gridsize; ++i)
     {
       var3[i] = var2[i];
-      if (!DBL_IS_EQUAL(var1[i], missval1))
+      if (!fp_is_equal(var1[i], missval1))
         {
-          if (!DBL_IS_EQUAL(var2[i], missval2))
+          if (!fp_is_equal(var2[i], missval2))
             var3[i] += var1[i];
           else
             var3[i] = var1[i];
@@ -43,13 +42,14 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "Vertcum",
-    .operators = { { "vertcum"}, { "vertcumhl"} },
+    .operators = { { "vertcum" }, { "vertcumhl" } },
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
     .constraints = { 1, 1, NoRestriction },
   };
   inline static RegisterEntry<Vertcum> registration = RegisterEntry<Vertcum>(module);
+
   int VERTCUMHL;
   int nlevshl = 0;
 
@@ -62,20 +62,19 @@ public:
 
   int operatorID;
 
-  int nvars;
+  int numVars;
+
+  VarList varList1;
+  VarList varList2;
 
-  VarList varList1, varList2;
   std::vector<std::vector<size_t>> varnumMissVals;
   Varray3D<double> vardata1, vardata2;
 
 public:
   void
-  init()
+  init() override
   {
-
-    // clang-format off
-VERTCUMHL = module.get_id("vertcumhl");
-    // clang-format on
+    VERTCUMHL = module.get_id("vertcumhl");
 
     operatorID = cdo_operator_id();
 
@@ -92,7 +91,7 @@ VERTCUMHL = module.get_id("vertcumhl");
       {
         std::vector<double> vct;
         bool lhybrid = false;
-        auto nzaxis = vlistNzaxis(vlistID1);
+        auto nzaxis = vlistNumZaxis(vlistID1);
         for (int i = 0; i < nzaxis; ++i)
           {
             auto zaxisID = vlistZaxis(vlistID1, i);
@@ -128,19 +127,19 @@ VERTCUMHL = module.get_id("vertcumhl");
           }
       }
 
-    varList_init(varList1, vlistID1);
-    varList_init(varList2, vlistID2);
+    varList1 = VarList(vlistID1);
+    varList2 = VarList(vlistID2);
 
-    nvars = vlistNvars(vlistID1);
-    varnumMissVals = std::vector<std::vector<size_t>>(nvars);
-    vardata1 = Varray3D<double>(nvars);
-    vardata2 = Varray3D<double>(nvars);
+    numVars = vlistNvars(vlistID1);
+    varnumMissVals = std::vector<std::vector<size_t>>(numVars);
+    vardata1 = Varray3D<double>(numVars);
+    vardata2 = Varray3D<double>(numVars);
 
-    for (int varID = 0; varID < nvars; ++varID)
+    for (int varID = 0; varID < numVars; ++varID)
       {
-        auto gridsize = varList1[varID].gridsize;
-        auto nlevs = varList1[varID].nlevels;
-        auto nlevs2 = varList2[varID].nlevels;
+        auto gridsize = varList1.vars[varID].gridsize;
+        auto nlevs = varList1.vars[varID].nlevels;
+        auto nlevs2 = varList2.vars[varID].nlevels;
 
         varnumMissVals[varID].resize(nlevs);
         vardata1[varID].resize(nlevs);
@@ -158,7 +157,7 @@ VERTCUMHL = module.get_id("vertcumhl");
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -171,16 +170,16 @@ VERTCUMHL = module.get_id("vertcumhl");
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
-            int varID, levelID;
-            cdo_inq_record(streamID1, &varID, &levelID);
+            auto [varID, levelID] = cdo_inq_record(streamID1);
             cdo_read_record(streamID1, &vardata1[varID][levelID][0], &varnumMissVals[varID][levelID]);
           }
 
-        for (int varID = 0; varID < nvars; ++varID)
+        for (int varID = 0; varID < numVars; ++varID)
           {
-            auto missval = varList2[varID].missval;
-            auto gridsize = varList2[varID].gridsize;
-            auto nlevs2 = varList2[varID].nlevels;
+            const auto &var2 = varList2.vars[varID];
+            auto missval = var2.missval;
+            auto gridsize = var2.gridsize;
+            auto nlevs2 = var2.nlevels;
 
             if (operatorID == VERTCUMHL && nlevs2 == nlevshl)
               {
@@ -202,26 +201,27 @@ VERTCUMHL = module.get_id("vertcumhl");
 
             if (operatorID == VERTCUMHL && nlevs2 == nlevshl)
               {
-                const auto &var1 = vardata2[varID][nlevs2 - 1];
+                const auto &var1data = vardata2[varID][nlevs2 - 1];
                 for (int levelID = 0; levelID < nlevs2; ++levelID)
                   {
-                    auto &var2 = vardata2[varID][levelID];
+                    auto &var2data = vardata2[varID][levelID];
                     for (size_t i = 0; i < gridsize; ++i)
                       {
-                        if (is_not_equal(var1[i], 0))
-                          var2[i] /= var1[i];
+                        if (is_not_equal(var1data[i], 0))
+                          var2data[i] /= var1data[i];
                         else
-                          var2[i] = 0;
+                          var2data[i] = 0;
                       }
                   }
               }
           }
 
-        for (int varID = 0; varID < nvars; ++varID)
+        for (int varID = 0; varID < numVars; ++varID)
           {
-            auto missval = varList2[varID].missval;
-            auto gridsize = varList2[varID].gridsize;
-            auto nlevs2 = varList2[varID].nlevels;
+            const auto &var2 = varList2.vars[varID];
+            auto missval = var2.missval;
+            auto gridsize = var2.gridsize;
+            auto nlevs2 = var2.nlevels;
             for (int levelID = 0; levelID < nlevs2; ++levelID)
               {
                 auto &single = vardata2[varID][levelID];
@@ -236,7 +236,7 @@ VERTCUMHL = module.get_id("vertcumhl");
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
