@@ -8,7 +8,7 @@
 #include <cmath>
 
 #include "cdo_options.h"
-#include "cimdOmp.h"
+#include "cdo_omp.h"
 #include "constants.h"
 #include "varray.h"
 #include "gaussian_latitudes.h"
