@@ -16,10 +16,15 @@
 #include <udunits2.h>
 #endif
 
-void cdo_convert_free(void *ut_converter);
-void cdo_convert_destroy();
+namespace cdo
+{
+void convert_free(void *ut_converter);
+void convert_destroy();
+}  // namespace cdo
 #endif
 
-void cdo_convert_units(void **ut_converter, bool *changeunits, char *units, char *units_old, const char *name);
-
+namespace cdo
+{
+void convert_units(void **ut_converter, bool *changeunits, char *units, char *units_old, const char *name);
+}
 #endif  // __CONVERT_UNITS_H_
