@@ -376,12 +376,12 @@ static void compute_edge_middle_point_vec(
   double middle[3]) {
 
   YAC_ASSERT(
-    (edge_type == GREAT_CIRCLE_EDGE) ||
-    (edge_type == LAT_CIRCLE_EDGE) ||
-    (edge_type == LON_CIRCLE_EDGE),
+    (edge_type == YAC_GREAT_CIRCLE_EDGE) ||
+    (edge_type == YAC_LAT_CIRCLE_EDGE) ||
+    (edge_type == YAC_LON_CIRCLE_EDGE),
     "ERROR(compute_edge_middle_point_vec): invalide edge_type")
 
-  if (edge_type == LAT_CIRCLE_EDGE) {
+  if (edge_type == YAC_LAT_CIRCLE_EDGE) {
     middle[0] = a[0]+b[0], middle[1] = a[1]+b[1], middle[2] = a[2];
     double temp = middle[0]*middle[0] + middle[1]*middle[1];
     double scale = sqrt((1.0 - middle[2] * middle[2])/temp);
@@ -474,7 +474,7 @@ static int yac_identical_gcxgc_vec(
 
   return
     yac_identical_circles_vec(
-      GREAT_CIRCLE_EDGE, a, b, c, d, p, q,
+      YAC_GREAT_CIRCLE_EDGE, a, b, c, d, p, q,
       (vector_is_between(c, d, a, sq_len_diff_cd) << 0) +
       (vector_is_between(c, d, b, sq_len_diff_cd) << 1) +
       (vector_is_between(a, b, c, sq_len_diff_ab) << 2) +
@@ -576,7 +576,7 @@ static int yac_latcxlatc_vec(
   else
     return
       yac_identical_circles_vec(
-        LAT_CIRCLE_EDGE, a, b, c, d, p, q,
+        YAC_LAT_CIRCLE_EDGE, a, b, c, d, p, q,
         (vector_is_between_lat(c, d, a) << 0) +
         (vector_is_between_lat(c, d, b) << 1) +
         (vector_is_between_lat(a, b, c) << 2) +
@@ -789,12 +789,12 @@ int yac_intersect_vec (
   double p[3], double q[3]) {
 
   YAC_ASSERT(
-    ((edge_type_a == LON_CIRCLE_EDGE) ||
-     (edge_type_a == LAT_CIRCLE_EDGE) ||
-     (edge_type_a == GREAT_CIRCLE_EDGE)) &&
-    ((edge_type_b == LON_CIRCLE_EDGE) ||
-     (edge_type_b == LAT_CIRCLE_EDGE) ||
-     (edge_type_b == GREAT_CIRCLE_EDGE)), "ERROR: unknown edge type.")
+    ((edge_type_a == YAC_LON_CIRCLE_EDGE) ||
+     (edge_type_a == YAC_LAT_CIRCLE_EDGE) ||
+     (edge_type_a == YAC_GREAT_CIRCLE_EDGE)) &&
+    ((edge_type_b == YAC_LON_CIRCLE_EDGE) ||
+     (edge_type_b == YAC_LAT_CIRCLE_EDGE) ||
+     (edge_type_b == YAC_GREAT_CIRCLE_EDGE)), "ERROR: unknown edge type.")
 
   int edge_a_is_point = points_are_identically(a, b);
   int edge_b_is_point = points_are_identically(c, d);
@@ -813,15 +813,15 @@ int yac_intersect_vec (
 
     int ret_value;
     switch (edge_type[edge_a_is_point]) {
-      case (LAT_CIRCLE_EDGE):
+      case (YAC_LAT_CIRCLE_EDGE):
         ret_value =
           yac_pxlat_vec(
             point[edge_a_is_point], 
             edge[edge_a_is_point][0], edge[edge_a_is_point][1], p, q);
         break;
       default:
-      case (LON_CIRCLE_EDGE):
-      case (GREAT_CIRCLE_EDGE):
+      case (YAC_LON_CIRCLE_EDGE):
+      case (YAC_GREAT_CIRCLE_EDGE):
         ret_value =
           yac_pxgc_vec(
             point[edge_a_is_point], 
@@ -833,48 +833,48 @@ int yac_intersect_vec (
     else                 return adjust_ret_value(ret_value);
 
    // if both edges are on circles of latitude
-  } else if (edge_type_a == LAT_CIRCLE_EDGE &&
-             edge_type_b == LAT_CIRCLE_EDGE) {
+  } else if (edge_type_a == YAC_LAT_CIRCLE_EDGE &&
+             edge_type_b == YAC_LAT_CIRCLE_EDGE) {
 
     return yac_latcxlatc_vec(a, b, c, d, p, q);
 
   // if both edges are on circle of longitude
-  } else if (edge_type_a == LON_CIRCLE_EDGE &&
-             edge_type_b == LON_CIRCLE_EDGE) {
+  } else if (edge_type_a == YAC_LON_CIRCLE_EDGE &&
+             edge_type_b == YAC_LON_CIRCLE_EDGE) {
 
     return yac_loncxlonc_vec(a, b, c, d, p, q);
 
   // if both edges are on great circles
-  } else if ((edge_type_a == GREAT_CIRCLE_EDGE &&
-              edge_type_b == GREAT_CIRCLE_EDGE) ||
-             (edge_type_a == LON_CIRCLE_EDGE   &&
-              edge_type_b == GREAT_CIRCLE_EDGE) ||
-             (edge_type_a == GREAT_CIRCLE_EDGE &&
-              edge_type_b == LON_CIRCLE_EDGE)) {
+  } else if ((edge_type_a == YAC_GREAT_CIRCLE_EDGE &&
+              edge_type_b == YAC_GREAT_CIRCLE_EDGE) ||
+             (edge_type_a == YAC_LON_CIRCLE_EDGE   &&
+              edge_type_b == YAC_GREAT_CIRCLE_EDGE) ||
+             (edge_type_a == YAC_GREAT_CIRCLE_EDGE &&
+              edge_type_b == YAC_LON_CIRCLE_EDGE)) {
 
     return yac_gcxgc_vec(a, b, c, d, p, q);
 
   // if one edge a is on a great circle and edge b on a circle of latitude
-  } else if (edge_type_a == GREAT_CIRCLE_EDGE &&
-             edge_type_b == LAT_CIRCLE_EDGE) {
+  } else if (edge_type_a == YAC_GREAT_CIRCLE_EDGE &&
+             edge_type_b == YAC_LAT_CIRCLE_EDGE) {
 
     return yac_gcxlatc_vec(a, b, c, d, p, q);
 
   // if one edge a is on a circle of latitude and edge b on a great circle
-  } else if (edge_type_a == LAT_CIRCLE_EDGE &&
-             edge_type_b == GREAT_CIRCLE_EDGE ) {
+  } else if (edge_type_a == YAC_LAT_CIRCLE_EDGE &&
+             edge_type_b == YAC_GREAT_CIRCLE_EDGE ) {
 
     return adjust_ret_value(yac_gcxlatc_vec(c, d, a, b, p, q));
 
   // if one edge a is on a circle of longitude and edge b on a circle of latitude
-  } else if (edge_type_a == LON_CIRCLE_EDGE &&
-             edge_type_b == LAT_CIRCLE_EDGE) {
+  } else if (edge_type_a == YAC_LON_CIRCLE_EDGE &&
+             edge_type_b == YAC_LAT_CIRCLE_EDGE) {
 
     return yac_loncxlatc_vec(a, b, c, d, p, q);
 
   // if one edge a is on a circle of latitude and edge b on a circle of longitude
-  } else /* if (edge_type_a == LAT_CIRCLE_EDGE &&
-             edge_type_b == LON_CIRCLE_EDGE )*/ {
+  } else /* if (edge_type_a == YAC_LAT_CIRCLE_EDGE &&
+             edge_type_b == YAC_LON_CIRCLE_EDGE )*/ {
 
     return adjust_ret_value(yac_loncxlatc_vec(c, d, a, b, p, q));
   }
@@ -891,13 +891,19 @@ int yac_point_on_edge(
     (circle_type == POINT),
     "ERROR(yac_point_on_edge): unknown edge type.")
 
+  YAC_ASSERT(
+    (circle_type != LAT_CIRCLE) || (fabs(a[2] - b[2]) < tol),
+    "ERROR(yac_point_on_edge): "
+    "LAT_CIRCLE but edge vertices do not have the same latitude");
+
   switch (circle_type) {
     default:
     case (GREAT_CIRCLE):
     case (LON_CIRCLE):
       return vector_is_between(a, b, p, sq_len_diff_vec(a, b));
     case (LAT_CIRCLE):
-      return vector_is_between_lat(a, b, p);
+      if (fabs(p[2] - a[2]) < tol) return vector_is_between_lat(a, b, p);
+      return 0;
     case(POINT):
       return points_are_identically(p, a);
   }
